
#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_a_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.120457'}

wordnet_terms_a = [
    'aa',
    'aaa',
    'aabba',
    'aachen',
    'aah',
    'aahed',
    'aalborg',
    'aalii',
    'aalst',
    'aalto',
    'aar',
    'aardvark',
    'aardvarks',
    'aardwolf',
    'aare',
    'aarhus',
    'aaron',
    'aarp',
    'aas',
    'aave',
    'ab',
    'aba',
    'abab',
    'abababcc',
    'abaca',
    'abacinate',
    'abacinated',
    'aback',
    'abactinal',
    'abacus',
    'abadan',
    'abaft',
    'abalone',
    'abalones',
    'abamp',
    'abampere',
    'abandon',
    'abandoned',
    'abandoning',
    'abandonment',
    'abandons',
    'abarticulation',
    'abase',
    'abasement',
    'abash',
    'abashed',
    'abashment',
    'abasia',
    'abasic',
    'abatable',
    'abate',
    'abated',
    'abatement',
    'abates',
    'abatic',
    'abatis',
    'abator',
    'abattis',
    'abattoir',
    'abaxial',
    'abaya',
    'abb',
    'abbacy',
    'abbatial',
    'abbe',
    'abbess',
    'abbey',
    'abbot',
    'abbreviate',
    'abbreviated',
    'abbreviation',
    'abbreviations',
    'abbreviator',
    'abc',
    'abcoulomb',
    'abcs',
    'abdias',
    'abdicable',
    'abdicate',
    'abdicated',
    'abdicating',
    'abdication',
    'abdicator',
    'abdomen',
    'abdominal',
    'abdominocentesis',
    'abdominoplasty',
    'abdominous',
    'abdominousness',
    'abdominovesical',
    'abduce',
    'abducens',
    'abducent',
    'abduct',
    'abducted',
    'abducting',
    'abduction',
    'abductor',
    'abducts',
    'abecedarian',
    'abecedarius',
    'abel',
    'abelard',
    'abele',
    'abelia',
    'abelmoschus',
    'abelmosk',
    'abenaki',
    'aberdare',
    'aberdeen',
    'aberdonian',
    'aberrance',
    'aberrancy',
    'aberrant',
    'aberrate',
    'aberrated',
    'aberration',
    'abet',
    'abetalipoproteinemia',
    'abetment',
    'abettal',
    'abetter',
    'abetting',
    'abettor',
    'abeyance',
    'abeyant',
    'abfarad',
    'abhenry',
    'abhor',
    'abhorred',
    'abhorrence',
    'abhorrent',
    'abhorrer',
    'abhors',
    'abidance',
    'abide',
    'abiding',
    'abidjan',
    'abience',
    'abient',
    'abies',
    'abila',
    'abilene',
    'abilities',
    'ability',
    'abiogenesis',
    'abiogenetic',
    'abiogenist',
    'abiotrophy',
    'abject',
    'abjection',
    'abjectly',
    'abjuration',
    'abjure',
    'abjured',
    'abjurer',
    'abjures',
    'abkazia',
    'abkhas',
    'abkhasian',
    'abkhaz',
    'abkhazia',
    'abkhazian',
    'ablactate',
    'ablactation',
    'ablate',
    'ablated',
    'ablation',
    'ablative',
    'ablaut',
    'ablaze',
    'able',
    'ableism',
    'ablepharia',
    'ablism',
    'abloom',
    'abls',
    'ablution',
    'ablutionary',
    'ablutions',
    'abm',
    'abnaki',
    'abnakis',
    'abnegate',
    'abnegated',
    'abnegation',
    'abnegator',
    'abnormal',
    'abnormalcy',
    'abnormalities',
    'abnormality',
    'abnormally',
    'aboard',
    'abocclusion',
    'abode',
    'abohm',
    'abolish',
    'abolishable',
    'abolished',
    'abolishes',
    'abolishing',
    'abolishment',
    'abolition',
    'abolitionary',
    'abolitionism',
    'abolitionist',
    'abolitionists',
    'abomasal',
    'abomasum',
    'abominable',
    'abominate',
    'abomination',
    'abominator',
    'abor',
    'aboral',
    'aboriginal',
    'aborigine',
    'aborigines',
    'abort',
    'aborticide',
    'abortifacient',
    'aborting',
    'abortion',
    'abortionist',
    'abortive',
    'abortus',
    'aboulia',
    'aboulic',
    'abound',
    'abounded',
    'abounding',
    'about',
    'above',
    'aboveboard',
    'aboveground',
    'abracadabra',
    'abrachia',
    'abradant',
    'abrade',
    'abraded',
    'abrader',
    'abrades',
    'abraham',
    'abramis',
    'abranchial',
    'abranchiate',
    'abranchious',
    'abrase',
    'abrasion',
    'abrasions',
    'abrasive',
    'abrasiveness',
    'abrasives',
    'abreact',
    'abreaction',
    'abreast',
    'abridge',
    'abridged',
    'abridgement',
    'abridger',
    'abridges',
    'abridgment',
    'abroach',
    'abroad',
    'abrocoma',
    'abrocome',
    'abrocomes',
    'abrogate',
    'abrogation',
    'abrogator',
    'abronia',
    'abrupt',
    'abruption',
    'abruptly',
    'abruptness',
    'abruzzi',
    'abs',
    'abscess',
    'abscessed',
    'abscesses',
    'abscise',
    'abscissa',
    'abscission',
    'abscond',
    'absconded',
    'absconder',
    'abscondment',
    'abseil',
    'abseiler',
    'absence',
    'absent',
    'absented',
    'absentee',
    'absenteeism',
    'absentminded',
    'absentmindedness',
    'absinth',
    'absinthe',
    'absolute',
    'absolutely',
    'absoluteness',
    'absolutes',
    'absolution',
    'absolutism',
    'absolutist',
    'absolutistic',
    'absolve',
    'absolved',
    'absolver',
    'absolving',
    'absolvitory',
    'absorb',
    'absorbable',
    'absorbance',
    'absorbate',
    'absorbed',
    'absorbefacient',
    'absorbency',
    'absorbent',
    'absorber',
    'absorbers',
    'absorbing',
    'absorbs',
    'absorptance',
    'absorption',
    'absorptive',
    'absorptivity',
    'absquatulate',
    'abstain',
    'abstained',
    'abstainer',
    'abstaining',
    'abstemious',
    'abstemiousness',
    'abstention',
    'abstentious',
    'abstinence',
    'abstinent',
    'abstract',
    'abstracted',
    'abstractedness',
    'abstracter',
    'abstracting',
    'abstraction',
    'abstractionism',
    'abstractionist',
    'abstractions',
    'abstractive',
    'abstractly',
    'abstractness',
    'abstractor',
    'abstracts',
    'abstruse',
    'abstruseness',
    'abstrusity',
    'absurd',
    'absurdity',
    'absurdly',
    'absurdness',
    'abu',
    'abudefduf',
    'abuja',
    'abukir',
    'abulia',
    'abulic',
    'abundance',
    'abundant',
    'abundantly',
    'abuse',
    'abused',
    'abuser',
    'abusers',
    'abuses',
    'abusing',
    'abusive',
    'abut',
    'abutilon',
    'abutment',
    'abuts',
    'abutter',
    'abutting',
    'abuzz',
    'abvolt',
    'abwatt',
    'aby',
    'abydos',
    'abye',
    'abyla',
    'abysm',
    'abysmal',
    'abyss',
    'abyssal',
    'abyssinia',
    'abyssinian',
    'ac',
    'acacia',
    'academe',
    'academia',
    'academic',
    'academician',
    'academicianship',
    'academicism',
    'academics',
    'academism',
    'academy',
    'acadia',
    'acadian',
    'acadians',
    'acalypha',
    'acantha',
    'acanthaceae',
    'acanthion',
    'acanthisitta',
    'acanthisittidae',
    'acanthocephala',
    'acanthocephalan',
    'acanthocereus',
    'acanthocybium',
    'acanthocyte',
    'acanthocytes',
    'acanthocytosis',
    'acanthoid',
    'acantholysis',
    'acanthoma',
    'acanthophis',
    'acanthopterygian',
    'acanthopterygii',
    'acanthoscelides',
    'acanthosis',
    'acanthotic',
    'acanthous',
    'acanthuridae',
    'acanthurus',
    'acanthus',
    'acapnia',
    'acapnial',
    'acapnic',
    'acapnotic',
    'acapulco',
    'acaracide',
    'acardia',
    'acariasis',
    'acaricide',
    'acarid',
    'acaridae',
    'acaridiasis',
    'acarina',
    'acarine',
    'acariosis',
    'acaroid',
    'acarophobia',
    'acarpellous',
    'acarpelous',
    'acarpous',
    'acarus',
    'acaryote',
    'acatalectic',
    'acataphasia',
    'acathexia',
    'acathexis',
    'acaudal',
    'acaudate',
    'acaulescent',
    'acc',
    'accede',
    'acceding',
    'accelerando',
    'accelerate',
    'accelerated',
    'accelerates',
    'accelerating',
    'acceleration',
    'accelerative',
    'accelerator',
    'accelerators',
    'acceleratory',
    'accelerometer',
    'accent',
    'accented',
    'accenting',
    'accentor',
    'accents',
    'accentual',
    'accentuate',
    'accentuated',
    'accentuates',
    'accentuation',
    'accept',
    'acceptability',
    'acceptable',
    'acceptableness',
    'acceptably',
    'acceptance',
    'acceptant',
    'acceptation',
    'accepted',
    'accepting',
    'acceptive',
    'acceptor',
    'acceptors',
    'accepts',
    'access',
    'accessary',
    'accessed',
    'accesses',
    'accessibility',
    'accessible',
    'accessing',
    'accession',
    'accessional',
    'accessorial',
    'accessories',
    'accessory',
    'accho',
    'acciaccatura',
    'accidence',
    'accident',
    'accidental',
    'accidentally',
    'accidentals',
    'accidents',
    'accipiter',
    'accipitridae',
    'accipitriformes',
    'accipitrine',
    'acclaim',
    'acclaimed',
    'acclamation',
    'acclimate',
    'acclimation',
    'acclimatisation',
    'acclimatise',
    'acclimatization',
    'acclimatize',
    'acclimatized',
    'acclivitous',
    'acclivity',
    'accolade',
    'accommodate',
    'accommodated',
    'accommodates',
    'accommodating',
    'accommodation',
    'accommodational',
    'accommodations',
    'accommodative',
    'accommodator',
    'accompanied',
    'accompanies',
    'accompaniment',
    'accompanist',
    'accompany',
    'accompanying',
    'accompanyist',
    'accomplice',
    'accomplices',
    'accomplish',
    'accomplishable',
    'accomplished',
    'accomplishes',
    'accomplishing',
    'accomplishment',
    'accomplishments',
    'accord',
    'accordance',
    'accordant',
    'accorded',
    'according',
    'accordingly',
    'accordion',
    'accordionist',
    'accords',
    'accost',
    'accosting',
    'accouchement',
    'accoucheur',
    'accoucheuse',
    'account',
    'accountability',
    'accountable',
    'accountancy',
    'accountant',
    'accountants',
    'accountantship',
    'accounted',
    'accounting',
    'accounts',
    'accouter',
    'accoutered',
    'accouterment',
    'accoutre',
    'accoutred',
    'accoutrement',
    'accra',
    'accredit',
    'accreditation',
    'accredited',
    'accrete',
    'accreted',
    'accretion',
    'accretionary',
    'accretions',
    'accretive',
    'accroides',
    'accrual',
    'accrue',
    'accrued',
    'accruement',
    'accruing',
    'acculturate',
    'acculturation',
    'acculturational',
    'acculturative',
    'accumbent',
    'accumulate',
    'accumulated',
    'accumulates',
    'accumulating',
    'accumulation',
    'accumulations',
    'accumulative',
    'accumulator',
    'accuracy',
    'accurate',
    'accurately',
    'accurse',
    'accursed',
    'accurst',
    'accusal',
    'accusation',
    'accusations',
    'accusative',
    'accusatorial',
    'accusatory',
    'accuse',
    'accused',
    'accuser',
    'accusers',
    'accusing',
    'accusive',
    'accustom',
    'accustomed',
    'ace',
    'acebutolol',
    'aced',
    'acedia',
    'acellular',
    'acentric',
    'acephalia',
    'acephalism',
    'acephalous',
    'acephaly',
    'acer',
    'aceraceae',
    'acerate',
    'acerb',
    'acerbate',
    'acerbic',
    'acerbity',
    'acerola',
    'acerose',
    'acervate',
    'acervulus',
    'aces',
    'acetabular',
    'acetabulum',
    'acetal',
    'acetaldehyde',
    'acetaldol',
    'acetals',
    'acetamide',
    'acetaminophen',
    'acetanilid',
    'acetanilide',
    'acetate',
    'acetates',
    'acetic',
    'acetify',
    'acetin',
    'acetone',
    'acetonemia',
    'acetonic',
    'acetonuria',
    'acetophenetidin',
    'acetose',
    'acetous',
    'acetphenetidin',
    'acetum',
    'acetyl',
    'acetylate',
    'acetylated',
    'acetylation',
    'acetylcholine',
    'acetylene',
    'acetylenic',
    'acetylic',
    'acetylise',
    'acetylize',
    'achaea',
    'achaean',
    'achaian',
    'ache',
    'ached',
    'achene',
    'achenes',
    'achenial',
    'acheron',
    'acheronian',
    'acherontia',
    'acherontic',
    'aches',
    'acheson',
    'acheta',
    'achievability',
    'achievable',
    'achieve',
    'achieved',
    'achievement',
    'achievements',
    'achiever',
    'achieves',
    'achieving',
    'achillea',
    'achilles',
    'achimenes',
    'aching',
    'achira',
    'achlamydeous',
    'achlorhydria',
    'achlorhydric',
    'achoerodus',
    'acholia',
    'achomawi',
    'achondrite',
    'achondritic',
    'achondroplasia',
    'achondroplastic',
    'achondroplasty',
    'achras',
    'achromasia',
    'achromatic',
    'achromaticity',
    'achromatin',
    'achromatinic',
    'achromatise',
    'achromatism',
    'achromatize',
    'achromatous',
    'achromia',
    'achromic',
    'achromous',
    'achromycin',
    'achy',
    'achylia',
    'acicula',
    'aciculae',
    'acicular',
    'aciculate',
    'acid',
    'acidemia',
    'acidic',
    'acidification',
    'acidify',
    'acidimetric',
    'acidimetry',
    'acidity',
    'acidophil',
    'acidophile',
    'acidophilic',
    'acidophilous',
    'acidophilus',
    'acidosis',
    'acidotic',
    'acids',
    'acidulate',
    'acidulent',
    'acidulous',
    'acidulousness',
    'aciduric',
    'acinar',
    'acinic',
    'acinonyx',
    'acinos',
    'acinose',
    'acinous',
    'acinus',
    'acipenser',
    'acipenseridae',
    'ackee',
    'acknowledge',
    'acknowledgeable',
    'acknowledged',
    'acknowledgement',
    'acknowledgements',
    'acknowledges',
    'acknowledging',
    'acknowledgment',
    'acknowledgments',
    'aclant',
    'acme',
    'acne',
    'acned',
    'acneiform',
    'acnidosporidia',
    'acocanthera',
    'acokanthera',
    'acold',
    'acolyte',
    'aconcagua',
    'aconite',
    'aconitum',
    'acoraceae',
    'acorea',
    'acores',
    'acorn',
    'acorns',
    'acorus',
    'acousma',
    'acoustic',
    'acoustical',
    'acoustically',
    'acoustician',
    'acousticophobia',
    'acoustics',
    'acquaint',
    'acquaintance',
    'acquaintanceship',
    'acquainted',
    'acquiesce',
    'acquiescence',
    'acquiescent',
    'acquirable',
    'acquire',
    'acquired',
    'acquirement',
    'acquirer',
    'acquires',
    'acquiring',
    'acquisition',
    'acquisitive',
    'acquisitiveness',
    'acquit',
    'acquittal',
    'acquittance',
    'acquitted',
    'acragas',
    'acrasiomycetes',
    'acre',
    'acreage',
    'acres',
    'acrid',
    'acridid',
    'acrididae',
    'acridity',
    'acridness',
    'acridotheres',
    'acrilan',
    'acrimonious',
    'acrimony',
    'acris',
    'acritical',
    'acroanaesthesia',
    'acroanesthesia',
    'acrobat',
    'acrobates',
    'acrobatic',
    'acrobatics',
    'acrobats',
    'acrocarp',
    'acrocarpous',
    'acrocarpus',
    'acrocentric',
    'acrocephalus',
    'acrocephaly',
    'acroclinium',
    'acrocomia',
    'acrocyanosis',
    'acrodont',
    'acrogen',
    'acrogenic',
    'acrogenous',
    'acrolein',
    'acromegalia',
    'acromegalic',
    'acromegaly',
    'acromicria',
    'acromikria',
    'acromion',
    'acromphalus',
    'acromyotonia',
    'acronym',
    'acronymic',
    'acronymous',
    'acronyms',
    'acropetal',
    'acrophobia',
    'acrophobic',
    'acrophony',
    'acropolis',
    'acropora',
    'acroscopic',
    'acrosome',
    'across',
    'acrostic',
    'acrostichum',
    'acrylamide',
    'acrylate',
    'acrylic',
    'acrylonitrile',
    'act',
    'actable',
    'actaea',
    'acted',
    'acth',
    'actias',
    'actifed',
    'actin',
    'actinal',
    'actinaria',
    'acting',
    'actinia',
    'actinian',
    'actiniaria',
    'actiniarian',
    'actinic',
    'actinide',
    'actinidia',
    'actinidiaceae',
    'actiniopteris',
    'actinism',
    'actinium',
    'actinoid',
    'actinolite',
    'actinomeris',
    'actinometer',
    'actinometric',
    'actinometrical',
    'actinometry',
    'actinomorphic',
    'actinomorphous',
    'actinomyces',
    'actinomycetaceae',
    'actinomycetal',
    'actinomycetales',
    'actinomycete',
    'actinomycetes',
    'actinomycetous',
    'actinomycin',
    'actinomycosis',
    'actinomycotic',
    'actinomyxidia',
    'actinomyxidian',
    'actinon',
    'actinopod',
    'actinopoda',
    'actinotherapy',
    'actinozoa',
    'actinozoan',
    'action',
    'actionable',
    'actioned',
    'actions',
    'actitis',
    'actium',
    'activase',
    'activate',
    'activated',
    'activates',
    'activating',
    'activation',
    'activator',
    'active',
    'actively',
    'activeness',
    'actives',
    'activewear',
    'activism',
    'activist',
    'activistic',
    'activists',
    'activities',
    'activity',
    'actomyosin',
    'actor',
    'actors',
    'actress',
    'actresses',
    'acts',
    'actual',
    'actualisation',
    'actualise',
    'actuality',
    'actualization',
    'actualize',
    'actually',
    'actuarial',
    'actuary',
    'actuate',
    'actuated',
    'actuates',
    'actuating',
    'actuation',
    'actuator',
    'acuate',
    'acuity',
    'acular',
    'aculea',
    'aculeate',
    'aculeated',
    'aculeus',
    'acumen',
    'acuminate',
    'acupressure',
    'acupuncture',
    'acute',
    'acutely',
    'acuteness',
    'acyclic',
    'acyclovir',
    'acyl',
    'acylation',
    'acylglycerol',
    'ad',
    'ada',
    'adactylia',
    'adactylism',
    'adactylous',
    'adactyly',
    'adad',
    'adage',
    'adagio',
    'adalia',
    'adam',
    'adamance',
    'adamant',
    'adamantine',
    'adams',
    'adana',
    'adansonia',
    'adapa',
    'adapid',
    'adapin',
    'adapt',
    'adaptability',
    'adaptable',
    'adaptation',
    'adaptational',
    'adaptations',
    'adaptative',
    'adapted',
    'adapter',
    'adapting',
    'adaption',
    'adaptive',
    'adaptor',
    'adapts',
    'adar',
    'adaxial',
    'add',
    'addable',
    'addax',
    'added',
    'addend',
    'addendum',
    'adder',
    'addible',
    'addict',
    'addicted',
    'addiction',
    'addictive',
    'addicts',
    'adding',
    'addition',
    'additional',
    'additions',
    'additive',
    'addle',
    'addlebrained',
    'addled',
    'addlehead',
    'addlepated',
    'address',
    'addressable',
    'addressed',
    'addressee',
    'addresses',
    'addressing',
    'addressograph',
    'adds',
    'adduce',
    'adducent',
    'adducer',
    'adducing',
    'adduct',
    'adducting',
    'adduction',
    'adductive',
    'adductor',
    'adducts',
    'ade',
    'adelaide',
    'adelges',
    'adelgid',
    'adelgidae',
    'adelie',
    'aden',
    'adenanthera',
    'adenauer',
    'adenine',
    'adenitis',
    'adenium',
    'adenocarcinoma',
    'adenocarcinomatous',
    'adenohypophysis',
    'adenoid',
    'adenoidal',
    'adenoidectomy',
    'adenoids',
    'adenoma',
    'adenomatous',
    'adenomegaly',
    'adenomyosarcoma',
    'adenomyosis',
    'adenopathy',
    'adenosine',
    'adenosis',
    'adenota',
    'adenovirus',
    'adept',
    'adeptness',
    'adequacy',
    'adequate',
    'adequately',
    'adequateness',
    'adermin',
    'adesite',
    'adh',
    'adhd',
    'adhere',
    'adhered',
    'adhereing',
    'adherence',
    'adherent',
    'adherents',
    'adheres',
    'adhering',
    'adhesion',
    'adhesions',
    'adhesive',
    'adhesiveness',
    'adhesives',
    'adhocracy',
    'adiabatic',
    'adiantaceae',
    'adiantum',
    'adience',
    'adient',
    'adieu',
    'adige',
    'adios',
    'adipose',
    'adiposeness',
    'adiposis',
    'adiposity',
    'adirondacks',
    'adit',
    'aditi',
    'aditya',
    'adityas',
    'adjacency',
    'adjacent',
    'adjectival',
    'adjectivally',
    'adjective',
    'adjectives',
    'adjoin',
    'adjoining',
    'adjoins',
    'adjourn',
    'adjourned',
    'adjournment',
    'adjudge',
    'adjudicate',
    'adjudicated',
    'adjudicating',
    'adjudication',
    'adjudicative',
    'adjudicator',
    'adjudicatory',
    'adjunct',
    'adjunction',
    'adjunctive',
    'adjuration',
    'adjuratory',
    'adjure',
    'adjust',
    'adjustable',
    'adjusted',
    'adjuster',
    'adjusting',
    'adjustive',
    'adjustment',
    'adjustments',
    'adjustor',
    'adjusts',
    'adjutant',
    'adjuvant',
    'adlumia',
    'adman',
    'admass',
    'admeasure',
    'administer',
    'administered',
    'administering',
    'administers',
    'administrable',
    'administrate',
    'administration',
    'administrative',
    'administrator',
    'administrators',
    'administrivia',
    'admirability',
    'admirable',
    'admirableness',
    'admiral',
    'admiralty',
    'admiration',
    'admire',
    'admired',
    'admirer',
    'admires',
    'admiring',
    'admissibility',
    'admissible',
    'admission',
    'admissive',
    'admit',
    'admits',
    'admittable',
    'admittance',
    'admitted',
    'admittible',
    'admitting',
    'admix',
    'admixed',
    'admixture',
    'admonish',
    'admonished',
    'admonisher',
    'admonishes',
    'admonishing',
    'admonishment',
    'admonition',
    'admonitory',
    'adnate',
    'adnexa',
    'adnexal',
    'adnoun',
    'ado',
    'adobe',
    'adobo',
    'adolesce',
    'adolescence',
    'adolescent',
    'adolescents',
    'adolf',
    'adolphus',
    'adonic',
    'adonis',
    'adopt',
    'adoptable',
    'adopted',
    'adoptee',
    'adopter',
    'adopting',
    'adoption',
    'adoptive',
    'adopts',
    'adorability',
    'adorable',
    'adorableness',
    'adoration',
    'adore',
    'adored',
    'adorer',
    'adoring',
    'adorn',
    'adorned',
    'adorning',
    'adornment',
    'adoxography',
    'adp',
    'adpressed',
    'adps',
    'adrenal',
    'adrenalectomy',
    'adrenalin',
    'adrenaline',
    'adrenarche',
    'adrenergic',
    'adrenocortical',
    'adrenocorticotrophic',
    'adrenocorticotrophin',
    'adrenocorticotropic',
    'adrenocorticotropin',
    'adrenosterone',
    'adrian',
    'adrianople',
    'adrianopolis',
    'adriatic',
    'adrift',
    'adroit',
    'adroitly',
    'adroitness',
    'ads',
    'adscititious',
    'adscript',
    'adscripted',
    'adsorb',
    'adsorbable',
    'adsorbate',
    'adsorbed',
    'adsorbent',
    'adsorbing',
    'adsorption',
    'adsorptive',
    'adulate',
    'adulation',
    'adulator',
    'adulatory',
    'adult',
    'adulterant',
    'adulterants',
    'adulterate',
    'adulterated',
    'adulterating',
    'adulteration',
    'adulterator',
    'adulterer',
    'adulterers',
    'adulteress',
    'adulterine',
    'adulterous',
    'adultery',
    'adulthood',
    'adults',
    'adumbrate',
    'adumbration',
    'adumbrative',
    'adust',
    'advance',
    'advanced',
    'advancement',
    'advancer',
    'advances',
    'advancing',
    'advantage',
    'advantageous',
    'advantageously',
    'advantageousness',
    'advantages',
    'advect',
    'advected',
    'advection',
    'advective',
    'advent',
    'adventism',
    'adventist',
    'adventitia',
    'adventitial',
    'adventitious',
    'adventive',
    'adventure',
    'adventurer',
    'adventurers',
    'adventures',
    'adventuresome',
    'adventuress',
    'adventurism',
    'adventuristic',
    'adventurous',
    'adventurousness',
    'adverb',
    'adverbial',
    'adversary',
    'adversative',
    'adverse',
    'adversities',
    'adversity',
    'advert',
    'advertence',
    'advertency',
    'advertent',
    'advertise',
    'advertised',
    'advertisement',
    'advertisements',
    'advertiser',
    'advertisers',
    'advertises',
    'advertising',
    'advertize',
    'advertizement',
    'advertizer',
    'advertizing',
    'advertorial',
    'advice',
    'advil',
    'advisability',
    'advisable',
    'advise',
    'advised',
    'advisee',
    'advisement',
    'adviser',
    'advisers',
    'advises',
    'advising',
    'advisor',
    'advisors',
    'advisory',
    'advocacy',
    'advocate',
    'advocated',
    'advocates',
    'advocating',
    'advocator',
    'advowson',
    'adynamia',
    'adynamic',
    'adz',
    'adze',
    'adzhar',
    'adzharia',
    'aec',
    'aecia',
    'aecial',
    'aeciospore',
    'aeciospores',
    'aecium',
    'aedes',
    'aegates',
    'aegean',
    'aegiceras',
    'aegilops',
    'aegina',
    'aegir',
    'aegis',
    'aegisthus',
    'aegospotami',
    'aegospotamos',
    'aegypiidae',
    'aegypius',
    'aegyptopithecus',
    'aeneas',
    'aeneid',
    'aengus',
    'aeolia',
    'aeolian',
    'aeolians',
    'aeolic',
    'aeolis',
    'aeolotropic',
    'aeolus',
    'aeon',
    'aeonian',
    'aeonium',
    'aepyceros',
    'aepyornidae',
    'aepyorniformes',
    'aepyornis',
    'aerate',
    'aerated',
    'aeration',
    'aerator',
    'aerial',
    'aerialist',
    'aerials',
    'aerides',
    'aerie',
    'aeriferous',
    'aeriform',
    'aerify',
    'aerobacter',
    'aerobatics',
    'aerobe',
    'aerobic',
    'aerobics',
    'aerobiosis',
    'aerobiotic',
    'aerodontalgia',
    'aerodrome',
    'aerodynamic',
    'aerodynamics',
    'aeroembolism',
    'aerofoil',
    'aerogenerator',
    'aerogram',
    'aerogramme',
    'aerolite',
    'aerolitic',
    'aerological',
    'aerology',
    'aeromechanic',
    'aeromechanics',
    'aeromedical',
    'aeromedicine',
    'aeronaut',
    'aeronautic',
    'aeronautical',
    'aeronautics',
    'aerophagia',
    'aerophilatelic',
    'aerophilately',
    'aerophile',
    'aerophilic',
    'aerophilous',
    'aerophyte',
    'aeroplane',
    'aerosol',
    'aerosolise',
    'aerosolised',
    'aerosolize',
    'aerosolized',
    'aerosols',
    'aerospace',
    'aertex',
    'aery',
    'aeschylean',
    'aeschylus',
    'aeschynanthus',
    'aesculapian',
    'aesculapius',
    'aesculus',
    'aesir',
    'aesop',
    'aesthesia',
    'aesthesis',
    'aesthete',
    'aesthetic',
    'aesthetical',
    'aesthetically',
    'aesthetician',
    'aesthetics',
    'aestival',
    'aestivate',
    'aestivation',
    'aether',
    'aethionema',
    'aethusa',
    'aetiologic',
    'aetiological',
    'aetiologist',
    'aetiology',
    'aetobatus',
    'af',
    'afebrile',
    'affability',
    'affable',
    'affableness',
    'affair',
    'affaire',
    'affairs',
    'affect',
    'affectation',
    'affectations',
    'affected',
    'affectedly',
    'affectedness',
    'affecting',
    'affection',
    'affectional',
    'affectionate',
    'affectionately',
    'affectionateness',
    'affections',
    'affective',
    'affects',
    'affenpinscher',
    'afferent',
    'affiance',
    'affiant',
    'affidavit',
    'affiliate',
    'affiliated',
    'affiliates',
    'affiliation',
    'affinal',
    'affine',
    'affined',
    'affinity',
    'affirm',
    'affirmable',
    'affirmation',
    'affirmative',
    'affirmatively',
    'affirmativeness',
    'affirmatory',
    'affirmed',
    'affirmer',
    'affirming',
    'affirms',
    'affix',
    'affixal',
    'affixation',
    'affixed',
    'affixes',
    'affixial',
    'affixing',
    'afflatus',
    'afflict',
    'afflicted',
    'affliction',
    'afflictions',
    'afflictive',
    'affluence',
    'affluent',
    'afford',
    'affordable',
    'afforded',
    'affording',
    'affords',
    'afforest',
    'afforestation',
    'affranchise',
    'affray',
    'affricate',
    'affrication',
    'affricative',
    'affright',
    'affront',
    'affusion',
    'afghan',
    'afghani',
    'afghanistan',
    'afghanistani',
    'afibrinogenemia',
    'aficionado',
    'afield',
    'afire',
    'afisr',
    'afl',
    'aflame',
    'aflare',
    'aflatoxin',
    'aflaxen',
    'afloat',
    'aflutter',
    'afoot',
    'aforementioned',
    'aforethought',
    'afoul',
    'afp',
    'afraid',
    'aframomum',
    'afrasian',
    'africa',
    'african',
    'africander',
    'africans',
    'afrikaans',
    'afrikander',
    'afrikaner',
    'afrl',
    'afro',
    'afroasiatic',
    'afrocarpus',
    'afropavo',
    'afspc',
    'aft',
    'after',
    'afterbirth',
    'afterburner',
    'aftercare',
    'afterdamp',
    'afterdeck',
    'aftereffect',
    'aftereffects',
    'afterglow',
    'afterimage',
    'afterlife',
    'aftermath',
    'aftermost',
    'afternoon',
    'afterpains',
    'afterpiece',
    'afters',
    'aftersensation',
    'aftershaft',
    'aftershafted',
    'aftershock',
    'aftertaste',
    'afterthought',
    'afterward',
    'afterworld',
    'ag',
    'aga',
    'again',
    'against',
    'agal',
    'agalactia',
    'agalactosis',
    'agalinis',
    'agama',
    'agamemnon',
    'agamete',
    'agamic',
    'agamid',
    'agamidae',
    'agammaglobulinemia',
    'agamogenesis',
    'agamogenetic',
    'agamous',
    'agapanthus',
    'agape',
    'agapornis',
    'agar',
    'agaric',
    'agaricaceae',
    'agaricales',
    'agarics',
    'agaricus',
    'agassiz',
    'agastache',
    'agate',
    'agateware',
    'agathis',
    'agavaceae',
    'agave',
    'agaze',
    'agdestis',
    'agdistis',
    'age',
    'aged',
    'agedness',
    'agee',
    'ageing',
    'ageism',
    'agelaius',
    'ageless',
    'agelessness',
    'agelong',
    'agencies',
    'agency',
    'agenda',
    'agendum',
    'agene',
    'agenesia',
    'agenesis',
    'agenise',
    'agenize',
    'agent',
    'agential',
    'agents',
    'agerasia',
    'ageratina',
    'ageratum',
    'ages',
    'aggeus',
    'agglomerate',
    'agglomerated',
    'agglomerating',
    'agglomeration',
    'agglomerative',
    'agglomerator',
    'agglutinate',
    'agglutinating',
    'agglutination',
    'agglutinative',
    'agglutinin',
    'agglutinogen',
    'aggrade',
    'aggrandise',
    'aggrandisement',
    'aggrandize',
    'aggrandizement',
    'aggravate',
    'aggravated',
    'aggravates',
    'aggravating',
    'aggravation',
    'aggravator',
    'aggregate',
    'aggregated',
    'aggregates',
    'aggregation',
    'aggregations',
    'aggregative',
    'aggregator',
    'aggress',
    'aggression',
    'aggressive',
    'aggressively',
    'aggressiveness',
    'aggressor',
    'aggrieve',
    'aggro',
    'aggroup',
    'agha',
    'aghan',
    'agile',
    'agility',
    'agincourt',
    'aging',
    'agio',
    'agiotage',
    'agism',
    'agitate',
    'agitated',
    'agitates',
    'agitating',
    'agitation',
    'agitative',
    'agitator',
    'agitprop',
    'agkistrodon',
    'aglaia',
    'aglaomorpha',
    'aglaonema',
    'agleam',
    'aglet',
    'aglow',
    'agnail',
    'agnate',
    'agnatha',
    'agnathan',
    'agnatic',
    'agnation',
    'agni',
    'agnise',
    'agnize',
    'agnomen',
    'agnosia',
    'agnostic',
    'agnostical',
    'agnosticism',
    'ago',
    'agog',
    'agon',
    'agonadal',
    'agonal',
    'agone',
    'agonidae',
    'agonise',
    'agonised',
    'agonising',
    'agonist',
    'agonistic',
    'agonistical',
    'agonize',
    'agonized',
    'agonizing',
    'agonus',
    'agony',
    'agora',
    'agoraphobia',
    'agoraphobic',
    'agorot',
    'agouti',
    'agoutis',
    'agra',
    'agranulocytic',
    'agranulocytosis',
    'agranulosis',
    'agrapha',
    'agraphia',
    'agraphic',
    'agrarian',
    'agree',
    'agreeability',
    'agreeable',
    'agreeableness',
    'agreeably',
    'agreed',
    'agreeing',
    'agreement',
    'agreements',
    'agrees',
    'agrestic',
    'agribusiness',
    'agricola',
    'agricultural',
    'agriculturalist',
    'agriculture',
    'agriculturist',
    'agrigento',
    'agrimonia',
    'agrimony',
    'agriocharis',
    'agrippa',
    'agrippina',
    'agrobacterium',
    'agrobiologic',
    'agrobiological',
    'agrobiology',
    'agrologic',
    'agrological',
    'agrology',
    'agromania',
    'agronomic',
    'agronomical',
    'agronomist',
    'agronomy',
    'agropyron',
    'agrostemma',
    'agrostis',
    'aground',
    'agrypnia',
    'agrypnotic',
    'agua',
    'aguacate',
    'ague',
    'agueweed',
    'aguish',
    'ahab',
    'ahead',
    'ahem',
    'ahimsa',
    'ahistorical',
    'ahmet',
    'ahorseback',
    'ahpcrc',
    'ahriman',
    'ahuehuete',
    'ahura',
    'ahvenanmaa',
    'ai',
    'aiai',
    'aid',
    'aide',
    'aided',
    'aides',
    'aiding',
    'aidoneus',
    'aids',
    'aigina',
    'aiglet',
    'aigret',
    'aigrette',
    'aiguilette',
    'aiken',
    'aikido',
    'ail',
    'ailanthus',
    'aileron',
    'ailerons',
    'ailey',
    'ailing',
    'ailment',
    'ailments',
    'ailurophobia',
    'ailuropoda',
    'ailuropodidae',
    'ailurus',
    'aim',
    'aimed',
    'aiming',
    'aimless',
    'aimlessly',
    'aimlessness',
    'aims',
    'ain',
    'ainu',
    'aioli',
    'air',
    'airborne',
    'airbrake',
    'airbrush',
    'airbrushed',
    'airburst',
    'airbus',
    'aircraft',
    'aircraftman',
    'aircraftsman',
    'aircrew',
    'aircrewman',
    'airdock',
    'airdrome',
    'airdrop',
    'aire',
    'aired',
    'airedale',
    'airedales',
    'aires',
    'airfare',
    'airfield',
    'airflow',
    'airfoil',
    'airfoils',
    'airforce',
    'airframe',
    'airfreight',
    'airgun',
    'airhead',
    'airheaded',
    'airiness',
    'airing',
    'airless',
    'airlift',
    'airlifted',
    'airlike',
    'airline',
    'airliner',
    'airliners',
    'airlock',
    'airmail',
    'airmailer',
    'airman',
    'airmanship',
    'airplane',
    'airplanes',
    'airport',
    'airports',
    'airpost',
    'airs',
    'airscrew',
    'airship',
    'airships',
    'airsick',
    'airsickness',
    'airspace',
    'airspeed',
    'airstream',
    'airstrip',
    'airt',
    'airtight',
    'airwave',
    'airwaves',
    'airway',
    'airways',
    'airwoman',
    'airworthiness',
    'airworthy',
    'airy',
    'aisle',
    'aisles',
    'aitchbone',
    'aix',
    'aizoaceae',
    'ajaia',
    'ajax',
    'ajuga',
    'ak',
    'akaba',
    'akan',
    'akaryocyte',
    'akaryote',
    'akee',
    'aken',
    'akeridae',
    'akha',
    'akhbari',
    'akhenaten',
    'akhenaton',
    'akin',
    'akinesia',
    'akinesis',
    'akka',
    'akkadian',
    'akko',
    'akmola',
    'akron',
    'aku',
    'akvavit',
    'al',
    'ala',
    'alabama',
    'alabaman',
    'alabamas',
    'alabamian',
    'alabaster',
    'alabastrine',
    'alacritous',
    'alacrity',
    'aladdin',
    'alae',
    'alalia',
    'alamo',
    'alamos',
    'alan',
    'aland',
    'alanine',
    'alar',
    'alaric',
    'alarm',
    'alarmed',
    'alarming',
    'alarmism',
    'alarmist',
    'alarms',
    'alarum',
    'alary',
    'alaska',
    'alaskan',
    'alastrim',
    'alate',
    'alated',
    'alauda',
    'alaudidae',
    'alb',
    'albacore',
    'albania',
    'albanian',
    'albanians',
    'albany',
    'albatrellus',
    'albatross',
    'albatrosses',
    'albedo',
    'albee',
    'albers',
    'albert',
    'alberta',
    'alberti',
    'albescent',
    'albidus',
    'albigenses',
    'albigensian',
    'albigensianism',
    'albinal',
    'albinic',
    'albinism',
    'albinistic',
    'albino',
    'albinotic',
    'albion',
    'albite',
    'albitic',
    'albizia',
    'albizzia',
    'alborg',
    'albuca',
    'albuginaceae',
    'albuginea',
    'albugo',
    'albula',
    'albulidae',
    'album',
    'albumen',
    'albumin',
    'albuminoid',
    'albuminous',
    'albuminuria',
    'albuminuric',
    'albums',
    'albuquerque',
    'albus',
    'albuterol',
    'alca',
    'alcaeus',
    'alcahest',
    'alcaic',
    'alcalde',
    'alcalescent',
    'alcapton',
    'alcaptonuria',
    'alcazar',
    'alcea',
    'alcedinidae',
    'alcedo',
    'alcelaphus',
    'alces',
    'alchemic',
    'alchemical',
    'alchemise',
    'alchemist',
    'alchemistic',
    'alchemistical',
    'alchemists',
    'alchemize',
    'alchemy',
    'alcibiades',
    'alcidae',
    'alcides',
    'alcohol',
    'alcoholic',
    'alcoholics',
    'alcoholise',
    'alcoholism',
    'alcoholize',
    'alcohols',
    'alcott',
    'alcove',
    'alcyonacea',
    'alcyonaria',
    'alcyone',
    'aldactone',
    'aldebaran',
    'aldehyde',
    'aldehydes',
    'aldehydic',
    'alder',
    'alderflies',
    'alderfly',
    'alderman',
    'aldermanic',
    'aldermanly',
    'aldermen',
    'alders',
    'aldohexose',
    'aldol',
    'aldomet',
    'aldose',
    'aldosterone',
    'aldosteronism',
    'aldous',
    'aldrovanda',
    'ale',
    'aleatory',
    'alecost',
    'alectis',
    'alecto',
    'alectoria',
    'alectoris',
    'alectura',
    'alehoof',
    'alehouse',
    'alembic',
    'alendronate',
    'alep',
    'aleph',
    'alepisaurus',
    'aleppo',
    'alert',
    'alerted',
    'alerting',
    'alertness',
    'aletris',
    'aleurites',
    'aleurone',
    'aleuronic',
    'aleut',
    'aleutian',
    'aleutians',
    'aleve',
    'alewife',
    'alex',
    'alexander',
    'alexanders',
    'alexandria',
    'alexandrian',
    'alexandrine',
    'alexandrite',
    'alexia',
    'alexic',
    'alexis',
    'aleyrodes',
    'aleyrodidae',
    'alfalfa',
    'alfilaria',
    'alfileria',
    'alfred',
    'alfresco',
    'alga',
    'algae',
    'algal',
    'algarobilla',
    'algarroba',
    'algarrobilla',
    'algebra',
    'algebraic',
    'algebraical',
    'algebraist',
    'alger',
    'algeria',
    'algerian',
    'algerie',
    'algeripithecus',
    'algid',
    'algidity',
    'algiers',
    'algin',
    'algoid',
    'algol',
    'algolagnia',
    'algolagnic',
    'algology',
    'algometer',
    'algometric',
    'algometrical',
    'algometry',
    'algonkian',
    'algonkin',
    'algonquian',
    'algonquians',
    'algonquin',
    'algophilia',
    'algophobia',
    'algophobic',
    'algorism',
    'algorithm',
    'algorithmic',
    'algorithms',
    'algren',
    'alhacen',
    'alhambra',
    'alhazen',
    'ali',
    'alias',
    'alibi',
    'alidad',
    'alidade',
    'alien',
    'alienable',
    'alienage',
    'alienate',
    'alienated',
    'alienating',
    'alienation',
    'alienator',
    'aliened',
    'alienee',
    'alienism',
    'alienist',
    'alienor',
    'aliens',
    'aliform',
    'alighieri',
    'alight',
    'align',
    'aligned',
    'aligning',
    'alignment',
    'aligns',
    'alike',
    'alikeness',
    'aliment',
    'alimental',
    'alimentary',
    'alimentation',
    'alimentative',
    'alimony',
    'aline',
    'alinement',
    'aliphatic',
    'aliquant',
    'aliquot',
    'alir',
    'alisma',
    'alismales',
    'alismataceae',
    'alismatidae',
    'alison',
    'aliterate',
    'alive',
    'aliveness',
    'aliyah',
    'alizarin',
    'alizarine',
    'alkahest',
    'alkahestic',
    'alkalemia',
    'alkalescent',
    'alkali',
    'alkalic',
    'alkalify',
    'alkalimetry',
    'alkaline',
    'alkalinise',
    'alkalinity',
    'alkalinize',
    'alkalinuria',
    'alkalis',
    'alkalise',
    'alkaliser',
    'alkalize',
    'alkalizer',
    'alkalizing',
    'alkaloid',
    'alkaloidal',
    'alkaloids',
    'alkalosis',
    'alkalotic',
    'alkaluria',
    'alkane',
    'alkanet',
    'alkapton',
    'alkaptonuria',
    'alkene',
    'alkeran',
    'alky',
    'alkyd',
    'alkyl',
    'alkylating',
    'alkylbenzene',
    'alkylbenzenesulfonate',
    'alkylic',
    'alkyne',
    'all',
    'allah',
    'allamanda',
    'allantoic',
    'allantoid',
    'allantois',
    'allargando',
    'allay',
    'allayer',
    'allaying',
    'allegation',
    'allegations',
    'allege',
    'alleged',
    'allegedly',
    'allegement',
    'alleges',
    'alleghenies',
    'allegheny',
    'allegiance',
    'allegiances',
    'allegiant',
    'alleging',
    'allegoric',
    'allegorical',
    'allegories',
    'allegorise',
    'allegoriser',
    'allegorize',
    'allegorized',
    'allegorizer',
    'allegory',
    'allegretto',
    'allegro',
    'allele',
    'alleles',
    'allelic',
    'allelomorph',
    'allelomorphic',
    'allemande',
    'allen',
    'allentown',
    'allergen',
    'allergenic',
    'allergens',
    'allergic',
    'allergies',
    'allergist',
    'allergology',
    'allergy',
    'alleviant',
    'alleviate',
    'alleviated',
    'alleviates',
    'alleviating',
    'alleviation',
    'alleviative',
    'alleviator',
    'alleviatory',
    'alley',
    'alleys',
    'alleyway',
    'allgood',
    'allhallows',
    'allhallowtide',
    'alliaceae',
    'alliaceous',
    'alliance',
    'alliances',
    'alliaria',
    'allice',
    'allied',
    'allies',
    'alligator',
    'alligatored',
    'alligatorfish',
    'alligatorfishes',
    'alligatoridae',
    'allionia',
    'allioniaceae',
    'allis',
    'alliterate',
    'alliteration',
    'alliterative',
    'alliterator',
    'allium',
    'allmouth',
    'alloantibody',
    'allocable',
    'allocatable',
    'allocate',
    'allocated',
    'allocating',
    'allocation',
    'allocations',
    'allocator',
    'allochronic',
    'allochthonous',
    'allocution',
    'allogamous',
    'allogamy',
    'allogeneic',
    'allograft',
    'allograph',
    'allographic',
    'allomerism',
    'allomerous',
    'allometric',
    'allometry',
    'allomorph',
    'allomorphic',
    'allomorphs',
    'allopathic',
    'allopathy',
    'allopatric',
    'allopatry',
    'allophone',
    'allophones',
    'allophonic',
    'allopurinol',
    'allosaur',
    'allosaurus',
    'allot',
    'allotment',
    'allotrope',
    'allotropes',
    'allotropic',
    'allotropical',
    'allotropism',
    'allotropy',
    'allotted',
    'allotting',
    'allover',
    'allow',
    'allowable',
    'allowance',
    'allowances',
    'allowed',
    'allowing',
    'allows',
    'alloy',
    'alloyed',
    'alloying',
    'alloys',
    'allspice',
    'allude',
    'alluded',
    'allure',
    'allurement',
    'alluring',
    'allusion',
    'allusions',
    'allusive',
    'allusiveness',
    'alluvial',
    'alluviation',
    'alluvion',
    'alluvium',
    'ally',
    'allyl',
    'allylic',
    'alma',
    'almanac',
    'almandine',
    'almandite',
    'almaty',
    'almighty',
    'almond',
    'almonds',
    'almoner',
    'almoravid',
    'almost',
    'alms',
    'almsgiver',
    'almsgiving',
    'alnico',
    'alnus',
    'alocasia',
    'aloe',
    'aloeaceae',
    'aloes',
    'aloft',
    'aloha',
    'alone',
    'aloneness',
    'along',
    'alongside',
    'alonso',
    'aloof',
    'aloofness',
    'alopecia',
    'alopecic',
    'alopecurus',
    'alopex',
    'alopiidae',
    'alopius',
    'alosa',
    'alouatta',
    'aloud',
    'alp',
    'alpaca',
    'alpena',
    'alpenstock',
    'alpestrine',
    'alpha',
    'alphabet',
    'alphabetic',
    'alphabetical',
    'alphabetically',
    'alphabetisation',
    'alphabetise',
    'alphabetised',
    'alphabetiser',
    'alphabetization',
    'alphabetize',
    'alphabetized',
    'alphabetizer',
    'alphameric',
    'alphamerical',
    'alphanumeric',
    'alphanumerical',
    'alphanumerics',
    'alphavirus',
    'alpine',
    'alpinia',
    'alpinism',
    'alpinist',
    'alprazolam',
    'alps',
    'already',
    'alright',
    'als',
    'alsace',
    'alsatia',
    'alsatian',
    'also',
    'alsobia',
    'alsophila',
    'alstonia',
    'alstroemeria',
    'alstroemeriaceae',
    'alt',
    'altace',
    'altai',
    'altaic',
    'altair',
    'altar',
    'altarpiece',
    'altazimuth',
    'alter',
    'alterability',
    'alterable',
    'alteration',
    'alterations',
    'alterative',
    'altercate',
    'altercation',
    'altered',
    'altering',
    'alternanthera',
    'alternate',
    'alternately',
    'alternates',
    'alternating',
    'alternation',
    'alternations',
    'alternative',
    'alternatively',
    'alternatives',
    'alternator',
    'alters',
    'althaea',
    'althea',
    'although',
    'altimeter',
    'altissimo',
    'altitude',
    'altitudes',
    'altitudinal',
    'altitudinous',
    'alto',
    'altocumulus',
    'altogether',
    'altoist',
    'altoona',
    'altostratus',
    'altricial',
    'altruism',
    'altruist',
    'altruistic',
    'alula',
    'alulae',
    'alular',
    'alum',
    'alumbloom',
    'alumina',
    'aluminate',
    'aluminiferous',
    'aluminise',
    'aluminium',
    'aluminize',
    'aluminous',
    'aluminum',
    'alumna',
    'alumni',
    'alumnus',
    'alumroot',
    'alundum',
    'alupent',
    'alveolar',
    'alveolate',
    'alveoli',
    'alveolitis',
    'alveolus',
    'alvine',
    'always',
    'alyssum',
    'alytes',
    'alzheimers',
    'am',
    'amadavat',
    'amadeus',
    'amaethon',
    'amah',
    'amalgam',
    'amalgamate',
    'amalgamated',
    'amalgamation',
    'amalgamative',
    'amalgamator',
    'amalgams',
    'amanita',
    'amanuensis',
    'amara',
    'amaranth',
    'amaranthaceae',
    'amaranthine',
    'amaranthus',
    'amarelle',
    'amaretto',
    'amarillo',
    'amaryllidaceae',
    'amaryllis',
    'amass',
    'amassed',
    'amassing',
    'amastia',
    'amaterasu',
    'amateur',
    'amateurish',
    'amateurishness',
    'amateurism',
    'amateurs',
    'amati',
    'amative',
    'amativeness',
    'amatory',
    'amatungulu',
    'amauropelta',
    'amaurosis',
    'amaurotic',
    'amaze',
    'amazed',
    'amazement',
    'amazes',
    'amazing',
    'amazingly',
    'amazon',
    'amazona',
    'amazons',
    'ambage',
    'ambages',
    'ambagious',
    'ambassador',
    'ambassadorial',
    'ambassadors',
    'ambassadorship',
    'ambassadress',
    'amber',
    'amberbell',
    'amberboa',
    'amberfish',
    'ambergris',
    'amberjack',
    'ambiance',
    'ambidexterity',
    'ambidextrous',
    'ambidextrousness',
    'ambience',
    'ambient',
    'ambiguities',
    'ambiguity',
    'ambiguous',
    'ambit',
    'ambition',
    'ambitionless',
    'ambitions',
    'ambitious',
    'ambitiousness',
    'ambivalence',
    'ambivalency',
    'ambivalent',
    'ambiversion',
    'ambiversive',
    'amble',
    'ambler',
    'ambloplites',
    'amblygonite',
    'amblyopia',
    'amblyopic',
    'amblyrhynchus',
    'ambo',
    'amboyna',
    'ambrose',
    'ambrosia',
    'ambrosiaceae',
    'ambrosial',
    'ambrosian',
    'ambulacra',
    'ambulacral',
    'ambulacrum',
    'ambulance',
    'ambulances',
    'ambulant',
    'ambulate',
    'ambulation',
    'ambulatory',
    'ambuscade',
    'ambush',
    'ambushed',
    'ambusher',
    'ambushing',
    'ambystoma',
    'ambystomatidae',
    'ambystomid',
    'amd',
    'ameba',
    'ameban',
    'amebas',
    'amebiasis',
    'amebic',
    'amebiosis',
    'ameboid',
    'amebous',
    'ameer',
    'ameiuridae',
    'ameiurus',
    'amelanchier',
    'amelia',
    'ameliorate',
    'ameliorated',
    'amelioration',
    'ameliorative',
    'amelioratory',
    'ameloblast',
    'amelogenesis',
    'amen',
    'amenability',
    'amenable',
    'amenableness',
    'amend',
    'amendable',
    'amendatory',
    'amended',
    'amending',
    'amendment',
    'amendments',
    'amends',
    'amenia',
    'amenities',
    'amenity',
    'amenorrhea',
    'amenorrheal',
    'amenorrheic',
    'amenorrhoea',
    'amenorrhoeal',
    'amenorrhoeic',
    'ament',
    'amentaceous',
    'amentia',
    'amentiferae',
    'amentiferous',
    'aments',
    'amerce',
    'amercement',
    'amerciable',
    'america',
    'american',
    'americana',
    'americanisation',
    'americanise',
    'americanism',
    'americanization',
    'americanize',
    'americanized',
    'americans',
    'americas',
    'americium',
    'amerind',
    'amerindian',
    'amerindians',
    'amerindic',
    'ametabolic',
    'ametabolous',
    'amethopterin',
    'amethyst',
    'amethystine',
    'ametria',
    'ametropia',
    'ametropic',
    'amex',
    'amhara',
    'amharic',
    'amia',
    'amiability',
    'amiable',
    'amiableness',
    'amianthum',
    'amicability',
    'amicable',
    'amicableness',
    'amid',
    'amide',
    'amidopyrine',
    'amidship',
    'amidships',
    'amigo',
    'amiidae',
    'amine',
    'amines',
    'aminic',
    'amino',
    'aminoaciduria',
    'aminoalkane',
    'aminobenzine',
    'aminomethane',
    'aminopherase',
    'aminophylline',
    'aminoplast',
    'aminopyrine',
    'aminotransferase',
    'amiodarone',
    'amir',
    'amish',
    'amitosis',
    'amitotic',
    'amitriptyline',
    'amity',
    'amman',
    'ammeter',
    'ammine',
    'ammino',
    'ammo',
    'ammobium',
    'ammodytes',
    'ammodytidae',
    'ammonia',
    'ammoniac',
    'ammoniacal',
    'ammoniate',
    'ammoniated',
    'ammonification',
    'ammonify',
    'ammonite',
    'ammonites',
    'ammonitic',
    'ammonium',
    'ammoniuria',
    'ammonoid',
    'ammotragus',
    'ammunition',
    'amnesia',
    'amnesiac',
    'amnesic',
    'amnestic',
    'amnesty',
    'amnic',
    'amnio',
    'amniocentesis',
    'amnion',
    'amnionic',
    'amnios',
    'amniota',
    'amniote',
    'amniotic',
    'amobarbital',
    'amoeba',
    'amoeban',
    'amoebas',
    'amoebiasis',
    'amoebic',
    'amoebida',
    'amoebina',
    'amoebiosis',
    'amoeboid',
    'amoebous',
    'amok',
    'amon',
    'among',
    'amontillado',
    'amor',
    'amora',
    'amoral',
    'amoralism',
    'amoralist',
    'amorality',
    'amorist',
    'amoristic',
    'amorous',
    'amorously',
    'amorousness',
    'amorpha',
    'amorphophallus',
    'amorphous',
    'amort',
    'amortisation',
    'amortise',
    'amortization',
    'amortize',
    'amos',
    'amount',
    'amounted',
    'amounting',
    'amounts',
    'amour',
    'amoxicillin',
    'amoxil',
    'amoy',
    'amp',
    'ampeloprasum',
    'amperage',
    'ampere',
    'amperes',
    'ampersand',
    'amphetamine',
    'amphetamines',
    'amphibia',
    'amphibian',
    'amphibians',
    'amphibiotic',
    'amphibious',
    'amphibole',
    'amphibolips',
    'amphibolite',
    'amphibology',
    'amphiboly',
    'amphibrach',
    'amphicarpa',
    'amphicarpaea',
    'amphictyony',
    'amphidiploid',
    'amphidiploidy',
    'amphigory',
    'amphimixis',
    'amphineura',
    'amphioxidae',
    'amphioxus',
    'amphipod',
    'amphipoda',
    'amphiprion',
    'amphiprostylar',
    'amphiprostyle',
    'amphiprotic',
    'amphisbaena',
    'amphisbaenia',
    'amphisbaenidae',
    'amphistylar',
    'amphitheater',
    'amphitheatre',
    'amphitheatric',
    'amphitheatrical',
    'amphitropous',
    'amphiuma',
    'amphiumidae',
    'amphora',
    'amphoric',
    'amphoteric',
    'amphotericin',
    'ampicillin',
    'ample',
    'ampleness',
    'amplification',
    'amplified',
    'amplifier',
    'amplifiers',
    'amplifies',
    'amplify',
    'amplifying',
    'amplitude',
    'ampoule',
    'ampul',
    'ampule',
    'ampulla',
    'ampullar',
    'ampullary',
    'amputate',
    'amputated',
    'amputation',
    'amputations',
    'amputator',
    'amputee',
    'amrinone',
    'amsinckia',
    'amsonia',
    'amsterdam',
    'amtrak',
    'amuck',
    'amulet',
    'amun',
    'amundsen',
    'amur',
    'amusd',
    'amuse',
    'amused',
    'amusement',
    'amusements',
    'amuses',
    'amusing',
    'amusive',
    'amy',
    'amygdala',
    'amygdalaceae',
    'amygdaliform',
    'amygdalin',
    'amygdaline',
    'amygdaloid',
    'amygdaloidal',
    'amygdalotomy',
    'amygdalus',
    'amyl',
    'amylaceous',
    'amylase',
    'amyloid',
    'amyloidal',
    'amyloidosis',
    'amylolysis',
    'amylolytic',
    'amylum',
    'amyotonia',
    'amyotrophia',
    'amyotrophic',
    'amyotrophy',
    'amytal',
    'amyxia',
    'an',
    'ana',
    'anabantidae',
    'anabaptism',
    'anabaptist',
    'anabaptists',
    'anabas',
    'anabatic',
    'anabiosis',
    'anabiotic',
    'anabolic',
    'anabolism',
    'anabrus',
    'anacanthini',
    'anacardiaceae',
    'anacardium',
    'anachronic',
    'anachronism',
    'anachronistic',
    'anachronous',
    'anacin',
    'anaclinal',
    'anaclisis',
    'anaclitic',
    'anacoluthia',
    'anacoluthic',
    'anacoluthon',
    'anacoluthons',
    'anaconda',
    'anacondas',
    'anacyclus',
    'anadenanthera',
    'anadiplosis',
    'anadromous',
    'anaemia',
    'anaemic',
    'anaerobe',
    'anaerobic',
    'anaerobiotic',
    'anaesthesia',
    'anaesthetic',
    'anaesthetise',
    'anaesthetist',
    'anaesthetize',
    'anagallis',
    'anagasta',
    'anaglyph',
    'anaglyphic',
    'anaglyphical',
    'anaglyphs',
    'anaglyphy',
    'anaglyptic',
    'anaglyptical',
    'anagnost',
    'anagoge',
    'anagogic',
    'anagogical',
    'anagram',
    'anagrammatic',
    'anagrammatical',
    'anagrammatise',
    'anagrammatize',
    'anagrams',
    'anagyris',
    'anaheim',
    'anal',
    'analbuminemia',
    'analecta',
    'analects',
    'analeptic',
    'analgesia',
    'analgesic',
    'analgesics',
    'analgetic',
    'analog',
    'analogical',
    'analogies',
    'analogise',
    'analogist',
    'analogize',
    'analogous',
    'analogue',
    'analogy',
    'analphabet',
    'analphabetic',
    'analphabetism',
    'analysand',
    'analyse',
    'analyser',
    'analyses',
    'analysis',
    'analyst',
    'analytic',
    'analytical',
    'analyticity',
    'analyzable',
    'analyze',
    'analyzed',
    'analyzer',
    'analyzes',
    'analyzing',
    'anamnesis',
    'anamnestic',
    'anamorphic',
    'anamorphism',
    'anamorphosis',
    'ananas',
    'ananias',
    'anapaest',
    'anapaestic',
    'anapest',
    'anapestic',
    'anaphalis',
    'anaphase',
    'anaphasic',
    'anaphor',
    'anaphora',
    'anaphoric',
    'anaphrodisia',
    'anaphrodisiac',
    'anaphylactic',
    'anaphylaxis',
    'anaplasia',
    'anaplasmosis',
    'anaplastic',
    'anaplasty',
    'anaprox',
    'anapsid',
    'anapsida',
    'anapurna',
    'anarchic',
    'anarchical',
    'anarchism',
    'anarchist',
    'anarchistic',
    'anarchy',
    'anarhichadidae',
    'anarhichas',
    'anarthria',
    'anas',
    'anasa',
    'anasarca',
    'anasarcous',
    'anasazi',
    'anaspid',
    'anaspida',
    'anastalsis',
    'anastatica',
    'anastigmat',
    'anastigmatic',
    'anastomose',
    'anastomosis',
    'anastomotic',
    'anastomus',
    'anastrophe',
    'anastylosis',
    'anathema',
    'anathematisation',
    'anathematise',
    'anathematization',
    'anathematize',
    'anathemise',
    'anathemize',
    'anatidae',
    'anatoli',
    'anatolia',
    'anatolian',
    'anatomic',
    'anatomical',
    'anatomically',
    'anatomise',
    'anatomist',
    'anatomize',
    'anatomized',
    'anatomy',
    'anatotitan',
    'anatoxin',
    'anatropous',
    'anaxagoras',
    'anaximander',
    'anaximenes',
    'ancestor',
    'ancestors',
    'ancestral',
    'ancestress',
    'ancestry',
    'anchor',
    'anchorage',
    'anchored',
    'anchoring',
    'anchorite',
    'anchorites',
    'anchoritic',
    'anchorman',
    'anchorperson',
    'anchors',
    'anchovies',
    'anchovy',
    'anchusa',
    'anchylosis',
    'ancient',
    'ancientness',
    'ancients',
    'ancillary',
    'ancistrodon',
    'ancohuma',
    'ancylidae',
    'ancylose',
    'ancylostomatidae',
    'ancylus',
    'and',
    'andalucia',
    'andalusia',
    'andalusian',
    'andaman',
    'andante',
    'andantino',
    'andean',
    'andelmin',
    'andersen',
    'anderson',
    'andes',
    'andesite',
    'andhra',
    'andira',
    'andiron',
    'andirons',
    'andorra',
    'andorran',
    'andradite',
    'andrea',
    'andreaea',
    'andreaeales',
    'andrena',
    'andrenas',
    'andrenid',
    'andrenidae',
    'andrew',
    'andrews',
    'andrewsii',
    'andricus',
    'androecium',
    'androgen',
    'androgenesis',
    'androgenetic',
    'androgenic',
    'androgenous',
    'androgeny',
    'androglossia',
    'androgyne',
    'androgynous',
    'androgyny',
    'android',
    'andromeda',
    'androphobia',
    'andropogon',
    'androsterone',
    'andryala',
    'andvari',
    'andy',
    'ane',
    'anecdotal',
    'anecdote',
    'anecdotes',
    'anecdotic',
    'anecdotical',
    'anecdotist',
    'anechoic',
    'aneides',
    'anele',
    'anemia',
    'anemias',
    'anemic',
    'anemographic',
    'anemography',
    'anemometer',
    'anemometric',
    'anemometrical',
    'anemometry',
    'anemone',
    'anemonella',
    'anemones',
    'anemophilous',
    'anemopsis',
    'anencephalia',
    'anencephalic',
    'anencephalous',
    'anencephaly',
    'anergy',
    'aneroid',
    'anesthesia',
    'anesthesiologist',
    'anesthesiology',
    'anesthetic',
    'anesthetics',
    'anesthetise',
    'anesthetist',
    'anesthetize',
    'anesthetized',
    'anesthetizes',
    'anesthetizing',
    'anesthyl',
    'anestric',
    'anestrous',
    'anestrum',
    'anestrus',
    'anethum',
    'aneuploid',
    'aneuploidy',
    'aneurin',
    'aneurism',
    'aneurismal',
    'aneurismatic',
    'aneurysm',
    'aneurysmal',
    'aneurysmatic',
    'anew',
    'anfractuous',
    'ang',
    'angara',
    'angas',
    'angel',
    'angeles',
    'angelfish',
    'angelfishes',
    'angelic',
    'angelica',
    'angelical',
    'angelim',
    'angelique',
    'angelology',
    'angels',
    'angelus',
    'anger',
    'angered',
    'angers',
    'angevin',
    'angevine',
    'angiitis',
    'angina',
    'anginal',
    'anginose',
    'anginous',
    'angiocardiogram',
    'angiocarp',
    'angiocarpic',
    'angiocarpous',
    'angioedema',
    'angiogenesis',
    'angiogram',
    'angiography',
    'angiohemophilia',
    'angiologist',
    'angiology',
    'angioma',
    'angiomatous',
    'angiopathy',
    'angioplasty',
    'angiopteris',
    'angiosarcoma',
    'angioscope',
    'angiosperm',
    'angiospermae',
    'angiospermous',
    'angiosperms',
    'angiotelectasia',
    'angiotensin',
    'angiotonin',
    'angle',
    'angled',
    'angledozer',
    'angler',
    'anglerfish',
    'anglers',
    'angles',
    'anglesea',
    'anglesey',
    'anglewing',
    'angleworm',
    'anglia',
    'anglian',
    'anglican',
    'anglicanism',
    'anglicisation',
    'anglicise',
    'anglicised',
    'anglicism',
    'anglicization',
    'anglicize',
    'angling',
    'anglo',
    'anglomania',
    'anglophil',
    'anglophile',
    'anglophilia',
    'anglophilic',
    'anglophobe',
    'anglophobia',
    'anglophobic',
    'angola',
    'angolan',
    'angolese',
    'angora',
    'angostura',
    'angraecum',
    'angrecum',
    'angrily',
    'angriness',
    'angry',
    'angst',
    'angstrom',
    'anguidae',
    'anguilla',
    'anguillan',
    'anguillidae',
    'anguilliformes',
    'anguillula',
    'anguine',
    'anguis',
    'anguish',
    'anguished',
    'angular',
    'angularity',
    'angulate',
    'angulation',
    'angus',
    'angwantibo',
    'anhedonia',
    'anhidrosis',
    'anhima',
    'anhimidae',
    'anhinga',
    'anhingidae',
    'anhydride',
    'anhydrosis',
    'anhydrous',
    'ani',
    'anicteric',
    'anigozanthus',
    'anil',
    'anile',
    'aniline',
    'anima',
    'animadversion',
    'animadvert',
    'animal',
    'animalcule',
    'animalculum',
    'animalia',
    'animalisation',
    'animalise',
    'animalism',
    'animalistic',
    'animality',
    'animalization',
    'animalize',
    'animals',
    'animate',
    'animated',
    'animateness',
    'animating',
    'animation',
    'animatism',
    'animatistic',
    'animator',
    'animatronics',
    'anime',
    'animise',
    'animism',
    'animist',
    'animistic',
    'animize',
    'animosity',
    'animus',
    'anion',
    'anionic',
    'anions',
    'anise',
    'aniseed',
    'aniseikonia',
    'aniseikonic',
    'anisette',
    'anisogamete',
    'anisogametic',
    'anisogamic',
    'anisogamous',
    'anisogamy',
    'anisometric',
    'anisometropia',
    'anisometropic',
    'anisoptera',
    'anisotremus',
    'anisotropic',
    'anisotropy',
    'anita',
    'anjou',
    'ankara',
    'ankle',
    'anklebone',
    'ankles',
    'anklet',
    'anklets',
    'ankus',
    'ankyloglossia',
    'ankylosaur',
    'ankylosaurs',
    'ankylosaurus',
    'ankylose',
    'ankylosis',
    'ankylotic',
    'anlage',
    'ann',
    'anna',
    'annaba',
    'annalist',
    'annalistic',
    'annals',
    'annam',
    'annamese',
    'annamite',
    'annapolis',
    'annapurna',
    'anne',
    'anneal',
    'annealed',
    'annealing',
    'annelid',
    'annelida',
    'annelidan',
    'annelids',
    'annex',
    'annexa',
    'annexal',
    'annexation',
    'annexational',
    'annexe',
    'annexed',
    'anniellidae',
    'annihilate',
    'annihilated',
    'annihilating',
    'annihilation',
    'annihilative',
    'annihilator',
    'anniversary',
    'annon',
    'annona',
    'annonaceae',
    'annotate',
    'annotated',
    'annotating',
    'annotation',
    'annotator',
    'announce',
    'announced',
    'announcement',
    'announcements',
    'announcer',
    'announces',
    'announcing',
    'annoy',
    'annoyance',
    'annoyed',
    'annoyer',
    'annoying',
    'annoyingly',
    'annoys',
    'annual',
    'annually',
    'annualry',
    'annuals',
    'annuitant',
    'annuity',
    'annul',
    'annular',
    'annulate',
    'annulated',
    'annulet',
    'annulled',
    'annulling',
    'annulment',
    'annulus',
    'annum',
    'annunciate',
    'annunciation',
    'annunciator',
    'annunciatory',
    'annwfn',
    'annwn',
    'ano',
    'anoa',
    'anobiidae',
    'anodal',
    'anode',
    'anodic',
    'anodise',
    'anodize',
    'anodonta',
    'anodyne',
    'anoectochilus',
    'anoestrous',
    'anoestrum',
    'anoestrus',
    'anogramma',
    'anoint',
    'anointed',
    'anointer',
    'anointing',
    'anointment',
    'anoints',
    'anole',
    'anolis',
    'anomala',
    'anomalies',
    'anomalist',
    'anomalopidae',
    'anomalops',
    'anomalopteryx',
    'anomalous',
    'anomalousness',
    'anomaly',
    'anomia',
    'anomic',
    'anomie',
    'anomiidae',
    'anomy',
    'anonym',
    'anonymity',
    'anonymous',
    'anoperineal',
    'anopheles',
    'anopheline',
    'anopia',
    'anoplura',
    'anorak',
    'anorchia',
    'anorchidism',
    'anorchism',
    'anorectal',
    'anorectic',
    'anorexia',
    'anorexic',
    'anorexigenic',
    'anorgasmia',
    'anorthic',
    'anorthite',
    'anorthitic',
    'anorthography',
    'anorthopia',
    'anosmatic',
    'anosmia',
    'anosmic',
    'anostraca',
    'another',
    'anouilh',
    'anova',
    'anovulant',
    'anovulation',
    'anoxemia',
    'anoxemic',
    'anoxia',
    'anoxic',
    'anpu',
    'ans',
    'ansaid',
    'anselm',
    'anser',
    'anseres',
    'anseriformes',
    'anserinae',
    'anserine',
    'anshar',
    'answer',
    'answerability',
    'answerable',
    'answerableness',
    'answered',
    'answerer',
    'answering',
    'answers',
    'ant',
    'antabuse',
    'antacid',
    'antagonise',
    'antagonism',
    'antagonist',
    'antagonistic',
    'antagonize',
    'antagonizing',
    'antakiya',
    'antakya',
    'antalya',
    'antananarivo',
    'antapex',
    'antarctic',
    'antarctica',
    'antares',
    'antbird',
    'antbirds',
    'ante',
    'anteater',
    'anteaters',
    'antebellum',
    'antecede',
    'antecedence',
    'antecedency',
    'antecedent',
    'antechamber',
    'antecubital',
    'antedate',
    'antediluvial',
    'antediluvian',
    'antedon',
    'antedonidae',
    'antefix',
    'antelope',
    'antelopes',
    'antemeridian',
    'antemortem',
    'antenatal',
    'antenna',
    'antennae',
    'antennal',
    'antennaria',
    'antennariidae',
    'antennary',
    'antennas',
    'antenuptial',
    'antepartum',
    'antepenult',
    'antepenultima',
    'antepenultimate',
    'anterior',
    'anteriority',
    'anterograde',
    'anteroom',
    'anthelminthic',
    'anthelmintic',
    'anthem',
    'anthemis',
    'anther',
    'antheraea',
    'antheral',
    'anthericum',
    'antheridia',
    'antheridial',
    'antheridiophore',
    'antheridiophores',
    'antheridium',
    'antheropeas',
    'antherozoid',
    'anthers',
    'anthesis',
    'anthidium',
    'anthill',
    'anthills',
    'anthoceropsida',
    'anthoceros',
    'anthocerotaceae',
    'anthocerotales',
    'anthologise',
    'anthologist',
    'anthologize',
    'anthology',
    'anthonomus',
    'anthony',
    'anthophagous',
    'anthophilous',
    'anthophyllite',
    'anthophyta',
    'anthozoa',
    'anthozoan',
    'anthracis',
    'anthracite',
    'anthracitic',
    'anthracosis',
    'anthrax',
    'anthriscus',
    'anthropic',
    'anthropical',
    'anthropocentric',
    'anthropocentricity',
    'anthropocentrism',
    'anthropogenesis',
    'anthropogenetic',
    'anthropogenic',
    'anthropogeny',
    'anthropoid',
    'anthropoidal',
    'anthropoidea',
    'anthropoids',
    'anthropolatry',
    'anthropological',
    'anthropologist',
    'anthropologists',
    'anthropology',
    'anthropometric',
    'anthropometrical',
    'anthropometry',
    'anthropomorphic',
    'anthropomorphise',
    'anthropomorphism',
    'anthropomorphize',
    'anthropomorphous',
    'anthropophagite',
    'anthropophagous',
    'anthropophagus',
    'anthropophagy',
    'anthroposophy',
    'anthurium',
    'anthus',
    'anthyllis',
    'anti',
    'antiacid',
    'antiadrenergic',
    'antiaircraft',
    'antialiasing',
    'antianxiety',
    'antiapartheid',
    'antiarrhythmic',
    'antiauthoritarian',
    'antibacterial',
    'antibaryon',
    'antibaryons',
    'antibiosis',
    'antibiotic',
    'antibiotics',
    'antiblack',
    'antibodies',
    'antibody',
    'antic',
    'anticancer',
    'anticatalyst',
    'anticholinergic',
    'anticholinesterase',
    'antichrist',
    'anticipant',
    'anticipate',
    'anticipated',
    'anticipates',
    'anticipating',
    'anticipation',
    'anticipative',
    'anticipator',
    'anticipatory',
    'anticlimactic',
    'anticlimactical',
    'anticlimax',
    'anticlinal',
    'anticlockwise',
    'anticoagulant',
    'anticoagulation',
    'anticoagulative',
    'anticonvulsant',
    'anticonvulsants',
    'anticyclone',
    'anticyclonic',
    'antidepressant',
    'antidiabetic',
    'antidiarrheal',
    'antidiuretic',
    'antido',
    'antidorcas',
    'antidotal',
    'antidote',
    'antidromic',
    'antielectron',
    'antiemetic',
    'antiepileptic',
    'antiestablishmentarianism',
    'antiestablishmentism',
    'antifeminism',
    'antifeminist',
    'antiferromagnetic',
    'antiferromagnetism',
    'antifertility',
    'antiflatulent',
    'antifreeze',
    'antifungal',
    'antigen',
    'antigenic',
    'antigens',
    'antigone',
    'antigonia',
    'antigonus',
    'antigram',
    'antigua',
    'antiguan',
    'antiheretical',
    'antihero',
    'antihistamine',
    'antihypertensive',
    'antihypertensives',
    'antiknock',
    'antiknocking',
    'antilepton',
    'antilles',
    'antilocapra',
    'antilocapridae',
    'antilog',
    'antilogarithm',
    'antilope',
    'antimacassar',
    'antimagnetic',
    'antimalarial',
    'antimatter',
    'antimeson',
    'antimetabolite',
    'antimicrobial',
    'antimicrobic',
    'antimonial',
    'antimonic',
    'antimonious',
    'antimonopoly',
    'antimony',
    'antimuon',
    'antimycin',
    'antimycotic',
    'antineoplastic',
    'antineutrino',
    'antineutrinos',
    'antineutron',
    'antinode',
    'antinomasia',
    'antinomian',
    'antinomianism',
    'antinomy',
    'antioch',
    'antioxidant',
    'antiparallel',
    'antiparticle',
    'antiparticles',
    'antipasto',
    'antipathetic',
    'antipathetical',
    'antipathy',
    'antipersonnel',
    'antiperspirant',
    'antiphlogistic',
    'antiphon',
    'antiphonal',
    'antiphonary',
    'antiphons',
    'antiphony',
    'antiphrasis',
    'antipodal',
    'antipode',
    'antipodean',
    'antipodes',
    'antipollution',
    'antipope',
    'antipopes',
    'antiproton',
    'antiprotons',
    'antiprotozoal',
    'antipruritic',
    'antipsychotic',
    'antipyresis',
    'antipyretic',
    'antipyretics',
    'antiquarian',
    'antiquark',
    'antiquary',
    'antiquate',
    'antiquated',
    'antique',
    'antiques',
    'antiquing',
    'antiquities',
    'antiquity',
    'antiredeposition',
    'antirrhinum',
    'antis',
    'antisatellite',
    'antisemitic',
    'antisemitism',
    'antisepsis',
    'antiseptic',
    'antisepticize',
    'antisepticized',
    'antiseptics',
    'antiserum',
    'antisocial',
    'antispasmodic',
    'antistrophe',
    'antistrophic',
    'antisubmarine',
    'antisyphilitic',
    'antisyphilitica',
    'antitank',
    'antitauon',
    'antithesis',
    'antithetic',
    'antithetical',
    'antithyroid',
    'antitoxic',
    'antitoxin',
    'antitrade',
    'antitrades',
    'antitrust',
    'antitumor',
    'antitumour',
    'antitussive',
    'antitype',
    'antitypic',
    'antitypical',
    'antivenene',
    'antivenin',
    'antivert',
    'antiviral',
    'antiwar',
    'antler',
    'antlered',
    'antlers',
    'antlia',
    'antlion',
    'antlions',
    'antofagasta',
    'antonine',
    'antoninus',
    'antonio',
    'antonius',
    'antony',
    'antonym',
    'antonymous',
    'antonyms',
    'antonymy',
    'antrorse',
    'antrozous',
    'antrum',
    'ants',
    'antsy',
    'antum',
    'antwerp',
    'antwerpen',
    'anu',
    'anubis',
    'anunnaki',
    'anura',
    'anuran',
    'anuresis',
    'anuretic',
    'anuria',
    'anuric',
    'anurous',
    'anus',
    'anvers',
    'anvil',
    'anwar',
    'anxieties',
    'anxiety',
    'anxiolytic',
    'anxious',
    'anxiously',
    'anxiousness',
    'any',
    'anybody',
    'anyone',
    'anything',
    'anywhere',
    'anzac',
    'anzio',
    'aorist',
    'aoristic',
    'aorta',
    'aortae',
    'aortal',
    'aortic',
    'aortitis',
    'aotus',
    'aoudad',
    'apache',
    'apadana',
    'apalachicola',
    'apanage',
    'apar',
    'apart',
    'apartheid',
    'apartment',
    'apartments',
    'apathetic',
    'apathy',
    'apatite',
    'apatosaur',
    'apatosaurus',
    'apatura',
    'apc',
    'ape',
    'apeldoorn',
    'apelike',
    'apennines',
    'aper',
    'apercu',
    'aperea',
    'aperient',
    'aperiodic',
    'aperitif',
    'aperitifs',
    'aperture',
    'apertures',
    'apery',
    'apes',
    'apetalous',
    'apex',
    'aphaeresis',
    'aphaeretic',
    'aphagia',
    'aphakia',
    'aphakic',
    'aphanite',
    'aphanitic',
    'aphasia',
    'aphasic',
    'aphasmidia',
    'aphelion',
    'apheresis',
    'apheretic',
    'aphesis',
    'aphetic',
    'aphid',
    'aphididae',
    'aphidoidea',
    'aphids',
    'aphis',
    'aphonia',
    'aphonic',
    'aphorise',
    'aphorism',
    'aphorisms',
    'aphorist',
    'aphoristic',
    'aphorize',
    'aphotic',
    'aphriza',
    'aphrodisia',
    'aphrodisiac',
    'aphrodisiacal',
    'aphrodite',
    'aphrophora',
    'aphyllanthaceae',
    'aphyllanthes',
    'aphyllophorales',
    'aphyllous',
    'apia',
    'apiaceae',
    'apian',
    'apiarian',
    'apiarist',
    'apiary',
    'apical',
    'apiculate',
    'apicultural',
    'apiculture',
    'apiculturist',
    'apidae',
    'apios',
    'apis',
    'apish',
    'apishamore',
    'apium',
    'apivorous',
    'aplacental',
    'aplacophora',
    'aplacophoran',
    'aplanatic',
    'aplasia',
    'aplastic',
    'aplectrum',
    'aplite',
    'aplitic',
    'aplodontia',
    'aplodontiidae',
    'aplomb',
    'aplysia',
    'aplysiidae',
    'apnea',
    'apneic',
    'apnoeic',
    'apoapsis',
    'apocalypse',
    'apocalyptic',
    'apocalyptical',
    'apocarpous',
    'apochromatic',
    'apocope',
    'apocrine',
    'apocrypha',
    'apocryphal',
    'apocynaceae',
    'apocynaceous',
    'apocynum',
    'apodal',
    'apodeictic',
    'apodeme',
    'apodemus',
    'apodictic',
    'apodidae',
    'apodiformes',
    'apodous',
    'apoenzyme',
    'apogametic',
    'apogamic',
    'apogamous',
    'apogamy',
    'apogean',
    'apogee',
    'apogon',
    'apogonidae',
    'apoidea',
    'apojove',
    'apolemia',
    'apolitical',
    'apollinaire',
    'apollo',
    'apologetic',
    'apologetics',
    'apologia',
    'apologise',
    'apologist',
    'apologize',
    'apologized',
    'apologizing',
    'apologue',
    'apology',
    'apolune',
    'apomict',
    'apomictic',
    'apomictical',
    'apomixis',
    'apomorphine',
    'aponeurosis',
    'aponeurotic',
    'apopemptic',
    'apophasis',
    'apophatic',
    'apophatism',
    'apophthegm',
    'apophyseal',
    'apophysis',
    'apoplectic',
    'apoplectiform',
    'apoplectoid',
    'apoplexy',
    'apoptosis',
    'aporocactus',
    'aposelene',
    'aposematic',
    'aposiopesis',
    'aposiopetic',
    'apostasy',
    'apostate',
    'apostatise',
    'apostatize',
    'apostle',
    'apostles',
    'apostleship',
    'apostolic',
    'apostolical',
    'apostrophe',
    'apostrophic',
    'apostrophise',
    'apostrophize',
    'apothecary',
    'apothecia',
    'apothecial',
    'apothecium',
    'apothegm',
    'apothegmatic',
    'apothegmatical',
    'apothegms',
    'apotheose',
    'apotheosis',
    'apotheosise',
    'apotheosize',
    'apotropaic',
    'appal',
    'appalachia',
    'appalachian',
    'appalachians',
    'appall',
    'appalled',
    'appalling',
    'appaloosa',
    'appanage',
    'appanages',
    'apparantly',
    'apparatchik',
    'apparatus',
    'apparel',
    'appareled',
    'apparency',
    'apparent',
    'apparently',
    'apparentness',
    'apparition',
    'apparitional',
    'appeal',
    'appealable',
    'appealed',
    'appealing',
    'appealingly',
    'appealingness',
    'appeals',
    'appear',
    'appearance',
    'appearances',
    'appeared',
    'appearing',
    'appears',
    'appeasable',
    'appease',
    'appeased',
    'appeasement',
    'appeaser',
    'appeasing',
    'appellant',
    'appellate',
    'appellation',
    'appellative',
    'append',
    'appendage',
    'appendaged',
    'appendages',
    'appendant',
    'appendectomy',
    'appended',
    'appendicectomy',
    'appendicitis',
    'appendicle',
    'appendicular',
    'appendicularia',
    'appendix',
    'appends',
    'appenzeller',
    'apperceive',
    'apperception',
    'apperceptive',
    'appertain',
    'appetence',
    'appetencies',
    'appetency',
    'appetent',
    'appetiser',
    'appetising',
    'appetisingness',
    'appetite',
    'appetites',
    'appetitive',
    'appetizer',
    'appetizers',
    'appetizing',
    'appetizingness',
    'applaud',
    'applaudable',
    'applauded',
    'applauder',
    'applauds',
    'applause',
    'apple',
    'applecart',
    'applejack',
    'applemint',
    'apples',
    'applesauce',
    'applet',
    'appleton',
    'applewood',
    'appliance',
    'appliances',
    'applicability',
    'applicable',
    'applicance',
    'applicant',
    'applicants',
    'application',
    'applications',
    'applicative',
    'applicator',
    'applicatory',
    'applied',
    'applier',
    'applies',
    'applique',
    'apply',
    'applying',
    'appoggiatura',
    'appoint',
    'appointed',
    'appointee',
    'appointees',
    'appointing',
    'appointive',
    'appointment',
    'appointments',
    'apportion',
    'apportionable',
    'apportioned',
    'apportioning',
    'apportionment',
    'apposable',
    'appose',
    'apposite',
    'appositeness',
    'apposition',
    'appositional',
    'appositive',
    'appraisal',
    'appraise',
    'appraised',
    'appraiser',
    'appraising',
    'appreciable',
    'appreciably',
    'appreciate',
    'appreciated',
    'appreciates',
    'appreciating',
    'appreciation',
    'appreciative',
    'appreciativeness',
    'appreciator',
    'apprehend',
    'apprehended',
    'apprehender',
    'apprehending',
    'apprehends',
    'apprehensible',
    'apprehension',
    'apprehensive',
    'apprehensiveness',
    'apprentice',
    'apprenticed',
    'apprentices',
    'apprenticeship',
    'appressed',
    'apprisal',
    'apprise',
    'apprised',
    'apprize',
    'appro',
    'approach',
    'approachability',
    'approachable',
    'approached',
    'approaches',
    'approaching',
    'approbate',
    'approbation',
    'approbative',
    'approbatory',
    'appropriable',
    'appropriate',
    'appropriately',
    'appropriateness',
    'appropriation',
    'appropriations',
    'appropriative',
    'appropriator',
    'approval',
    'approve',
    'approved',
    'approver',
    'approves',
    'approving',
    'approvingly',
    'approximate',
    'approximated',
    'approximately',
    'approximates',
    'approximating',
    'approximation',
    'approximations',
    'approximative',
    'appurtenance',
    'appurtenant',
    'apr',
    'apractic',
    'apraxia',
    'apraxic',
    'apresoline',
    'apricot',
    'apricots',
    'april',
    'apron',
    'apropos',
    'apse',
    'apsidal',
    'apsis',
    'apsu',
    'apt',
    'aptenodytes',
    'apteral',
    'apterous',
    'apterygidae',
    'apterygiformes',
    'apteryx',
    'aptitude',
    'aptitudes',
    'aptitudinal',
    'aptly',
    'aptness',
    'apulia',
    'apus',
    'aqaba',
    'aqua',
    'aquacultural',
    'aquaculture',
    'aqualung',
    'aquamarine',
    'aquanaut',
    'aquaphobia',
    'aquaphobic',
    'aquaplane',
    'aquaria',
    'aquarium',
    'aquariums',
    'aquarius',
    'aquatic',
    'aquatics',
    'aquatint',
    'aquavit',
    'aqueduct',
    'aqueous',
    'aquicultural',
    'aquiculture',
    'aquifer',
    'aquiferous',
    'aquifoliaceae',
    'aquila',
    'aquilege',
    'aquilegia',
    'aquiline',
    'aquinas',
    'aquitaine',
    'aquitania',
    'ar',
    'ara',
    'arab',
    'arabesque',
    'arabia',
    'arabian',
    'arabic',
    'arabidopsis',
    'arability',
    'arabis',
    'arabist',
    'arable',
    'arabs',
    'araceae',
    'araceous',
    'arachis',
    'arachnid',
    'arachnida',
    'arachnidian',
    'arachnids',
    'arachnoid',
    'arachnophobia',
    'arafat',
    'arafura',
    'aragon',
    'aragonite',
    'araguaia',
    'araguaya',
    'arak',
    'aral',
    'arales',
    'aralia',
    'araliaceae',
    'aram',
    'aramaean',
    'aramaic',
    'arame',
    'aramean',
    'arameans',
    'aramus',
    'aran',
    'aranea',
    'araneae',
    'araneida',
    'araneidal',
    'araneidan',
    'araneus',
    'aranyaka',
    'arapaho',
    'arapahoe',
    'ararat',
    'arariba',
    'araroba',
    'aras',
    'arauca',
    'araucaria',
    'araucariaceae',
    'araujia',
    'arava',
    'arawak',
    'arawakan',
    'arawn',
    'araxes',
    'arb',
    'arbalest',
    'arbalist',
    'arbiter',
    'arbitrable',
    'arbitrage',
    'arbitrager',
    'arbitrageur',
    'arbitral',
    'arbitrament',
    'arbitrarily',
    'arbitrariness',
    'arbitrary',
    'arbitrate',
    'arbitration',
    'arbitrational',
    'arbitrative',
    'arbitrator',
    'arbitrement',
    'arbor',
    'arboraceous',
    'arborary',
    'arborea',
    'arboreal',
    'arboreous',
    'arborescent',
    'arboresque',
    'arboretum',
    'arborical',
    'arboriculture',
    'arboriculturist',
    'arboriform',
    'arborise',
    'arborist',
    'arborize',
    'arborolatry',
    'arborous',
    'arborvirus',
    'arborviruses',
    'arborvitae',
    'arbour',
    'arbovirus',
    'arboviruses',
    'arbutus',
    'arc',
    'arca',
    'arcade',
    'arcades',
    'arcadia',
    'arcadian',
    'arcadians',
    'arcadic',
    'arcane',
    'arcanum',
    'arccos',
    'arccosecant',
    'arccosine',
    'arccotangent',
    'arcdegree',
    'arced',
    'arcella',
    'arcellidae',
    'arceuthobium',
    'arch',
    'archaean',
    'archaebacteria',
    'archaebacterium',
    'archaeobacteria',
    'archaeologic',
    'archaeological',
    'archaeologist',
    'archaeology',
    'archaeopteryx',
    'archaeornis',
    'archaeornithes',
    'archaeozoic',
    'archaic',
    'archaicism',
    'archaise',
    'archaism',
    'archaist',
    'archaistic',
    'archaize',
    'archaizes',
    'archangel',
    'archangelic',
    'archangelica',
    'archangelical',
    'archangels',
    'archbishop',
    'archbishopric',
    'archdeacon',
    'archdeaconry',
    'archdiocesan',
    'archdiocese',
    'archducal',
    'archduchess',
    'archduchy',
    'archduke',
    'archean',
    'arched',
    'archegonia',
    'archegonial',
    'archegoniate',
    'archegonium',
    'archenteron',
    'archeobacteria',
    'archeologic',
    'archeological',
    'archeologist',
    'archeologists',
    'archeology',
    'archeopteryx',
    'archeozoic',
    'archepiscopal',
    'archer',
    'archerfish',
    'archerfishes',
    'archers',
    'archery',
    'arches',
    'archespore',
    'archesporial',
    'archesporium',
    'archetypal',
    'archetype',
    'archetypical',
    'archiannelid',
    'archiannelida',
    'archibald',
    'archidiaconal',
    'archidiaconate',
    'archidiskidon',
    'archiepiscopal',
    'archil',
    'archilochus',
    'archimandrite',
    'archimedes',
    'archine',
    'arching',
    'archipallium',
    'archipelagic',
    'archipelago',
    'architect',
    'architectonic',
    'architectonics',
    'architects',
    'architectural',
    'architecture',
    'architeuthis',
    'architrave',
    'archival',
    'archive',
    'archives',
    'archivist',
    'archness',
    'archosargus',
    'archosaur',
    'archosauria',
    'archosaurian',
    'archpriest',
    'archway',
    'arcidae',
    'arciform',
    'arcminute',
    'arco',
    'arcs',
    'arcsec',
    'arcsecant',
    'arcsecond',
    'arcsin',
    'arcsine',
    'arctan',
    'arctangent',
    'arctic',
    'arctictis',
    'arctiid',
    'arctiidae',
    'arctium',
    'arctocebus',
    'arctocephalus',
    'arctonyx',
    'arctostaphylos',
    'arctotis',
    'arcturus',
    'arcuate',
    'arcus',
    'arda',
    'ardea',
    'ardeb',
    'ardeidae',
    'ardennes',
    'ardent',
    'ardently',
    'ardisia',
    'ardor',
    'ardour',
    'ards',
    'arduous',
    'arduousness',
    'are',
    'area',
    'areal',
    'areas',
    'areaway',
    'areca',
    'arecaceae',
    'arecidae',
    'areflexia',
    'arena',
    'arenaceous',
    'arenaria',
    'arenaviridae',
    'arenavirus',
    'arendt',
    'arenga',
    'arenicolous',
    'areola',
    'areolae',
    'areolar',
    'areolate',
    'areopagite',
    'areopagus',
    'arequipa',
    'arere',
    'ares',
    'arete',
    'arethusa',
    'argal',
    'argali',
    'argasid',
    'argasidae',
    'argemone',
    'argent',
    'argentic',
    'argentiferous',
    'argentina',
    'argentine',
    'argentines',
    'argentinian',
    'argentinidae',
    'argentinosaur',
    'argentite',
    'argentous',
    'argil',
    'argillaceous',
    'argillite',
    'arginine',
    'argiope',
    'argiopidae',
    'argive',
    'argo',
    'argon',
    'argonaut',
    'argonauta',
    'argonautidae',
    'argonauts',
    'argonne',
    'argonon',
    'argos',
    'argosy',
    'argot',
    'arguable',
    'argue',
    'argued',
    'arguer',
    'argues',
    'argufy',
    'arguing',
    'argument',
    'argumentation',
    'argumentative',
    'arguments',
    'argun',
    'argus',
    'argusianus',
    'argyle',
    'argyll',
    'argynnis',
    'argyranthemum',
    'argyreia',
    'argyrodite',
    'argyrol',
    'argyrotaenia',
    'argyroxiphium',
    'arhant',
    'arhat',
    'arhus',
    'aria',
    'ariadne',
    'ariana',
    'arianism',
    'arianist',
    'arianrhod',
    'arianrod',
    'aricara',
    'arid',
    'aridity',
    'aridness',
    'aries',
    'arietta',
    'ariidae',
    'arikara',
    'aril',
    'ariled',
    'arillate',
    'arilus',
    'ariocarpus',
    'ariomma',
    'ariose',
    'arioso',
    'arisaema',
    'arisarum',
    'arise',
    'arisen',
    'arises',
    'arishth',
    'arising',
    'arista',
    'aristarchus',
    'aristocort',
    'aristocracy',
    'aristocrat',
    'aristocratic',
    'aristocratical',
    'aristocrats',
    'aristolochia',
    'aristolochiaceae',
    'aristolochiales',
    'aristopak',
    'aristophanes',
    'aristotelean',
    'aristotelia',
    'aristotelian',
    'aristotelianism',
    'aristotelic',
    'aristotle',
    'arithmancy',
    'arithmetic',
    'arithmetical',
    'arithmetician',
    'arity',
    'arius',
    'arizona',
    'arizonan',
    'arizonian',
    'arjuna',
    'ark',
    'arkansan',
    'arkansas',
    'arkansawyer',
    'arles',
    'arlington',
    'arm',
    'armada',
    'armadillidiidae',
    'armadillidium',
    'armadillo',
    'armadillos',
    'armageddon',
    'armagnac',
    'armament',
    'armamentarium',
    'armaments',
    'armata',
    'armature',
    'armband',
    'armchair',
    'armed',
    'armenia',
    'armeniaca',
    'armenian',
    'armenians',
    'armeria',
    'armet',
    'armful',
    'armguard',
    'armhole',
    'armies',
    'armiger',
    'armilla',
    'armillaria',
    'armillariella',
    'armillary',
    'armin',
    'arming',
    'arminian',
    'arminianism',
    'arminius',
    'armistice',
    'armless',
    'armlet',
    'armlike',
    'armoire',
    'armor',
    'armoracia',
    'armored',
    'armorer',
    'armorial',
    'armory',
    'armour',
    'armoured',
    'armourer',
    'armoury',
    'armpit',
    'armpits',
    'armrest',
    'armrests',
    'arms',
    'armstrong',
    'army',
    'armyworm',
    'armyworms',
    'arng',
    'arnhem',
    'arnica',
    'arno',
    'arnold',
    'arnoseris',
    'aroid',
    'aroma',
    'aromatherapy',
    'aromatic',
    'aromatise',
    'aromatize',
    'arose',
    'arouet',
    'around',
    'arousal',
    'arouse',
    'aroused',
    'arouser',
    'arouses',
    'arousing',
    'arp',
    'arpeggio',
    'arpent',
    'arquebus',
    'arrack',
    'arraign',
    'arraignment',
    'arrange',
    'arranged',
    'arrangement',
    'arrangements',
    'arranger',
    'arranges',
    'arranging',
    'arrant',
    'arras',
    'array',
    'arrayed',
    'arrears',
    'arrest',
    'arrested',
    'arrester',
    'arresting',
    'arrests',
    'arrhenatherum',
    'arrhenius',
    'arrhythmia',
    'arrhythmias',
    'arrhythmic',
    'arrhythmical',
    'arrival',
    'arrivals',
    'arrive',
    'arrived',
    'arrivederci',
    'arriver',
    'arrives',
    'arriving',
    'arriviste',
    'arroba',
    'arrogance',
    'arrogant',
    'arrogantly',
    'arrogate',
    'arrogation',
    'arrogator',
    'arrow',
    'arrowhead',
    'arrowroot',
    'arrows',
    'arrowsmith',
    'arrowworm',
    'arrowworms',
    'arroyo',
    'arse',
    'arsehole',
    'arsenal',
    'arsenate',
    'arsenic',
    'arsenical',
    'arsenide',
    'arsenious',
    'arsenopyrite',
    'arsine',
    'arson',
    'arsonist',
    'art',
    'artamidae',
    'artamus',
    'artaxerxes',
    'artefact',
    'artefactual',
    'artemia',
    'artemis',
    'artemisia',
    'arteria',
    'arterial',
    'arterialise',
    'arterialize',
    'arteriectasia',
    'arteriectasis',
    'arteries',
    'arteriogram',
    'arteriography',
    'arteriola',
    'arteriolar',
    'arteriole',
    'arterioles',
    'arteriolosclerosis',
    'arteriosclerosis',
    'arteriosclerotic',
    'arteriosus',
    'arteriovenous',
    'arteriovenus',
    'arteritis',
    'artery',
    'artesian',
    'artful',
    'artfully',
    'artfulness',
    'arthralgia',
    'arthralgic',
    'arthritic',
    'arthritis',
    'arthrocentesis',
    'arthrodesis',
    'arthrogram',
    'arthrography',
    'arthromere',
    'arthromeric',
    'arthropathy',
    'arthroplasty',
    'arthropod',
    'arthropoda',
    'arthropodal',
    'arthropodan',
    'arthropodous',
    'arthropods',
    'arthropteris',
    'arthroscope',
    'arthroscopy',
    'arthrospore',
    'arthrospores',
    'arthrosporic',
    'arthrosporous',
    'arthur',
    'arthurian',
    'artichoke',
    'artichokes',
    'article',
    'articled',
    'articles',
    'articular',
    'articulary',
    'articulate',
    'articulated',
    'articulateness',
    'articulates',
    'articulatio',
    'articulation',
    'articulations',
    'articulative',
    'articulator',
    'articulatory',
    'artifact',
    'artifacts',
    'artifactual',
    'artifice',
    'artificer',
    'artificial',
    'artificiality',
    'artificially',
    'artillery',
    'artilleryman',
    'artiodactyl',
    'artiodactyla',
    'artiodactylous',
    'artisan',
    'artisans',
    'artist',
    'artiste',
    'artistic',
    'artistry',
    'artists',
    'artless',
    'artlessness',
    'artocarpus',
    'artois',
    'arts',
    'artsd',
    'artwork',
    'arty',
    'aruba',
    'arugula',
    'arui',
    'arulo',
    'arum',
    'arundinaceous',
    'arundinaria',
    'arundo',
    'aruru',
    'arvicola',
    'aryan',
    'arytaenoid',
    'arytenoid',
    'as',
    'asadha',
    'asafetida',
    'asafoetida',
    'asahikawa',
    'asala',
    'asama',
    'asamiya',
    'asana',
    'asanga',
    'asarabacca',
    'asarh',
    'asarum',
    'asat',
    'asbestos',
    'asbestosis',
    'ascaphidae',
    'ascaphus',
    'ascariasis',
    'ascaridae',
    'ascaridia',
    'ascaris',
    'ascend',
    'ascendable',
    'ascendance',
    'ascendancy',
    'ascendant',
    'ascended',
    'ascendence',
    'ascendency',
    'ascendent',
    'ascender',
    'ascendible',
    'ascending',
    'ascends',
    'ascension',
    'ascensional',
    'ascensive',
    'ascent',
    'ascertain',
    'ascertainable',
    'ascertained',
    'ascertaining',
    'ascesis',
    'ascetic',
    'ascetical',
    'asceticism',
    'asch',
    'aschelminthes',
    'asci',
    'ascidiaceae',
    'ascidian',
    'ascii',
    'ascites',
    'ascitic',
    'asclepiad',
    'asclepiadaceae',
    'asclepiadaceous',
    'asclepias',
    'asclepius',
    'ascocarp',
    'ascocarpous',
    'ascocarps',
    'ascolichen',
    'ascoma',
    'ascomycete',
    'ascomycetes',
    'ascomycetous',
    'ascomycota',
    'ascomycotina',
    'ascophyllum',
    'ascorbic',
    'ascospore',
    'ascospores',
    'ascosporic',
    'ascosporous',
    'ascot',
    'ascribable',
    'ascribe',
    'ascribed',
    'ascribes',
    'ascription',
    'ascus',
    'asdic',
    'asean',
    'asekd',
    'asepsis',
    'aseptic',
    'asexual',
    'asexuality',
    'asexually',
    'asgard',
    'ash',
    'ashamed',
    'ashbin',
    'ashcake',
    'ashcan',
    'ashe',
    'ashen',
    'ashes',
    'asheville',
    'ashir',
    'ashkenazi',
    'ashkhabad',
    'ashlar',
    'ashore',
    'ashram',
    'ashton',
    'ashtoreth',
    'ashtray',
    'ashur',
    'ashurbanipal',
    'ashy',
    'asia',
    'asian',
    'asians',
    'asiatic',
    'aside',
    'asilidae',
    'asimina',
    'asimov',
    'asin',
    'asinine',
    'asininity',
    'asio',
    'ask',
    'askance',
    'askant',
    'asked',
    'asker',
    'askew',
    'asking',
    'asklepios',
    'asks',
    'asl',
    'aslant',
    'asleep',
    'aslope',
    'asmara',
    'asmera',
    'asocial',
    'asp',
    'aspadana',
    'aspalathus',
    'asparagaceae',
    'asparaginase',
    'asparagine',
    'asparagus',
    'aspartame',
    'aspartic',
    'aspect',
    'aspects',
    'aspectual',
    'aspen',
    'aspens',
    'asper',
    'aspergill',
    'aspergillaceae',
    'aspergillales',
    'aspergillosis',
    'aspergillus',
    'asperity',
    'aspers',
    'asperse',
    'aspersion',
    'aspersorium',
    'asperula',
    'asphalt',
    'asphaltic',
    'aspheric',
    'aspherical',
    'asphodel',
    'asphodelaceae',
    'asphodeline',
    'asphodelus',
    'asphyxia',
    'asphyxiate',
    'asphyxiated',
    'asphyxiating',
    'asphyxiation',
    'asphyxiator',
    'aspic',
    'aspidelaps',
    'aspidiotus',
    'aspidistra',
    'aspidophoroides',
    'aspinwall',
    'aspirant',
    'aspirate',
    'aspiration',
    'aspirations',
    'aspirator',
    'aspire',
    'aspired',
    'aspirer',
    'aspirin',
    'aspiring',
    'aspis',
    'aspleniaceae',
    'asplenium',
    'asquint',
    'ass',
    'assagai',
    'assail',
    'assailability',
    'assailable',
    'assailant',
    'assailed',
    'assam',
    'assamese',
    'assassin',
    'assassinate',
    'assassinated',
    'assassination',
    'assassinations',
    'assassinator',
    'assassins',
    'assault',
    'assaulted',
    'assaulter',
    'assaultive',
    'assaults',
    'assay',
    'assayed',
    'assayer',
    'assaying',
    'assays',
    'assegai',
    'assemblage',
    'assemble',
    'assembled',
    'assembler',
    'assembling',
    'assembly',
    'assemblyman',
    'assemblywoman',
    'assent',
    'assented',
    'assenter',
    'assentient',
    'assenting',
    'assents',
    'assert',
    'assertable',
    'asserted',
    'asserter',
    'asserting',
    'assertion',
    'assertions',
    'assertive',
    'assertiveness',
    'asserts',
    'asses',
    'assess',
    'assessable',
    'assessed',
    'assessee',
    'assesses',
    'assessing',
    'assessment',
    'assessor',
    'asset',
    'assets',
    'asseverate',
    'asseveration',
    'asseverator',
    'asshole',
    'assibilate',
    'assibilation',
    'assiduity',
    'assiduous',
    'assiduousness',
    'assign',
    'assignable',
    'assignation',
    'assigned',
    'assignee',
    'assigning',
    'assignment',
    'assignments',
    'assignor',
    'assigns',
    'assimilable',
    'assimilate',
    'assimilated',
    'assimilates',
    'assimilating',
    'assimilation',
    'assimilative',
    'assimilator',
    'assimilatory',
    'assisi',
    'assist',
    'assistance',
    'assistant',
    'assistants',
    'assisted',
    'assisting',
    'assistive',
    'assists',
    'assize',
    'assizes',
    'associability',
    'associable',
    'associableness',
    'associate',
    'associated',
    'associates',
    'associateship',
    'associating',
    'association',
    'associational',
    'associationism',
    'associations',
    'associative',
    'associatory',
    'assoil',
    'assonance',
    'assonant',
    'assonate',
    'assonated',
    'assort',
    'assorted',
    'assortment',
    'assouan',
    'assuage',
    'assuagement',
    'assuaging',
    'assuan',
    'assuasive',
    'assume',
    'assumed',
    'assumes',
    'assuming',
    'assumption',
    'assumptions',
    'assumptive',
    'assur',
    'assurance',
    'assurances',
    'assurbanipal',
    'assure',
    'assured',
    'assuredness',
    'assures',
    'assurgent',
    'assuring',
    'assyria',
    'assyrian',
    'assyrians',
    'assyriology',
    'astacidae',
    'astacura',
    'astacus',
    'astaire',
    'astana',
    'astarte',
    'astasia',
    'astatic',
    'astatine',
    'aster',
    'asteraceae',
    'astereognosis',
    'asteriated',
    'asterid',
    'asteridae',
    'asterion',
    'asterisk',
    'asterisked',
    'asterisks',
    'asterism',
    'asterismal',
    'asterisms',
    'astern',
    'asternal',
    'asteroid',
    'asteroidal',
    'asteroidea',
    'asteroids',
    'asterope',
    'asters',
    'asthenia',
    'asthenic',
    'asthenopia',
    'asthenosphere',
    'astheny',
    'asthma',
    'asthmatic',
    'astigmatic',
    'astigmatism',
    'astigmia',
    'astilbe',
    'astir',
    'astomatal',
    'astomatous',
    'astonied',
    'astonish',
    'astonished',
    'astonishing',
    'astonishingly',
    'astonishment',
    'astor',
    'astound',
    'astounded',
    'astounding',
    'astragal',
    'astragalar',
    'astragalus',
    'astrakhan',
    'astral',
    'astrantia',
    'astraphobia',
    'astray',
    'astreus',
    'astride',
    'astringe',
    'astringence',
    'astringency',
    'astringent',
    'astringes',
    'astrobiology',
    'astrocyte',
    'astrocytic',
    'astrodome',
    'astrodynamics',
    'astrogate',
    'astrogator',
    'astroglia',
    'astrolabe',
    'astrolatry',
    'astrologer',
    'astrological',
    'astrologist',
    'astrology',
    'astroloma',
    'astrometry',
    'astronaut',
    'astronautic',
    'astronautical',
    'astronautics',
    'astronauts',
    'astronavigation',
    'astronium',
    'astronomer',
    'astronomers',
    'astronomic',
    'astronomical',
    'astronomy',
    'astrophysical',
    'astrophysicist',
    'astrophysics',
    'astrophyton',
    'astropogon',
    'astute',
    'astuteness',
    'astylar',
    'asuncion',
    'asunder',
    'asur',
    'asura',
    'asurbanipal',
    'asvina',
    'asvins',
    'aswan',
    'asylum',
    'asymmetric',
    'asymmetrical',
    'asymmetry',
    'asymptomatic',
    'asymptote',
    'asymptotic',
    'asymptotically',
    'asynchronism',
    'asynchronous',
    'asynchrony',
    'asynclitism',
    'asyndetic',
    'asyndeton',
    'asynergia',
    'asynergic',
    'asynergy',
    'asystole',
    'at',
    'atabrine',
    'atactic',
    'atakapa',
    'atakapan',
    'atar',
    'ataractic',
    'atarax',
    'ataraxia',
    'ataraxic',
    'ataraxis',
    'ataturk',
    'atavism',
    'atavist',
    'atavistic',
    'ataxia',
    'ataxic',
    'ataxy',
    'atayalic',
    'ate',
    'atelectasis',
    'ateleiosis',
    'ateleiotic',
    'ateles',
    'atelier',
    'ateliosis',
    'aten',
    'atenolol',
    'atf',
    'athabascan',
    'athabaskan',
    'athanasianism',
    'athanasius',
    'athanor',
    'athapascan',
    'athapaskan',
    'athar',
    'atheism',
    'atheist',
    'atheistic',
    'atheistical',
    'atheists',
    'athelstan',
    'athena',
    'athenaeum',
    'athene',
    'atheneum',
    'athenian',
    'athenians',
    'athens',
    'atherinidae',
    'atherinopsis',
    'atherodyde',
    'atherogenesis',
    'atheroma',
    'atheromas',
    'atheromatic',
    'atheromatous',
    'atherosclerosis',
    'atherosclerotic',
    'atherurus',
    'athetosis',
    'athinai',
    'athiorhodaceae',
    'athlete',
    'athletes',
    'athletic',
    'athleticism',
    'athletics',
    'athodyd',
    'athos',
    'athrotaxis',
    'athyriaceae',
    'athyrium',
    'atilt',
    'ativan',
    'atlanta',
    'atlantic',
    'atlantides',
    'atlantis',
    'atlas',
    'atm',
    'atmometer',
    'atmosphere',
    'atmospheric',
    'atmospherical',
    'atmospherics',
    'atole',
    'atoll',
    'atom',
    'atomic',
    'atomisation',
    'atomise',
    'atomiser',
    'atomism',
    'atomistic',
    'atomistical',
    'atomization',
    'atomize',
    'atomized',
    'atomizer',
    'atoms',
    'aton',
    'atonal',
    'atonalism',
    'atonalistic',
    'atonality',
    'atone',
    'atoned',
    'atonement',
    'atonia',
    'atonic',
    'atonicity',
    'atoning',
    'atony',
    'atop',
    'atopic',
    'atopognosia',
    'atopognosis',
    'atopy',
    'atorvastatin',
    'atoxic',
    'atp',
    'atrabilious',
    'atrazine',
    'atresia',
    'atreus',
    'atria',
    'atrial',
    'atrichornis',
    'atrichornithidae',
    'atrioventricular',
    'atrip',
    'atriplex',
    'atrium',
    'atrocious',
    'atrociousness',
    'atrocities',
    'atrocity',
    'atropa',
    'atrophedema',
    'atrophic',
    'atrophied',
    'atrophies',
    'atrophy',
    'atropidae',
    'atropine',
    'atropos',
    'atrovent',
    'atsugewi',
    'attacapa',
    'attacapan',
    'attach',
    'attachable',
    'attache',
    'attached',
    'attaches',
    'attaching',
    'attachment',
    'attachments',
    'attack',
    'attacked',
    'attacker',
    'attackers',
    'attacking',
    'attacks',
    'attain',
    'attainability',
    'attainable',
    'attainableness',
    'attainder',
    'attained',
    'attaining',
    'attainment',
    'attains',
    'attaint',
    'attalea',
    'attar',
    'attemper',
    'attempt',
    'attempted',
    'attempter',
    'attempting',
    'attempts',
    'attend',
    'attendance',
    'attendant',
    'attended',
    'attendee',
    'attender',
    'attending',
    'attends',
    'attention',
    'attentional',
    'attentive',
    'attentively',
    'attentiveness',
    'attenuate',
    'attenuated',
    'attenuates',
    'attenuating',
    'attenuation',
    'attenuator',
    'attest',
    'attestant',
    'attestation',
    'attestator',
    'attested',
    'attester',
    'attesting',
    'attestor',
    'attests',
    'attic',
    'attica',
    'attics',
    'atticus',
    'attila',
    'attilio',
    'attire',
    'attired',
    'attitude',
    'attitudes',
    'attitudinal',
    'attitudinise',
    'attitudinize',
    'attlee',
    'attorn',
    'attorned',
    'attorney',
    'attorneyship',
    'attosecond',
    'attract',
    'attractable',
    'attracted',
    'attracter',
    'attracting',
    'attraction',
    'attractions',
    'attractive',
    'attractively',
    'attractiveness',
    'attractor',
    'attracts',
    'attributable',
    'attribute',
    'attributed',
    'attributes',
    'attributing',
    'attribution',
    'attributive',
    'attrited',
    'attrition',
    'attritional',
    'attune',
    'attuned',
    'atypic',
    'atypical',
    'atypicality',
    'atypically',
    'au',
    'auberge',
    'aubergine',
    'auburn',
    'auc',
    'auchincloss',
    'auckland',
    'auction',
    'auctioned',
    'auctioneer',
    'auctions',
    'auctorial',
    'aucuba',
    'audacious',
    'audaciousness',
    'audacity',
    'audad',
    'auden',
    'audenesque',
    'audibility',
    'audible',
    'audibleness',
    'audibly',
    'audience',
    'audiences',
    'audile',
    'audio',
    'audiocassette',
    'audiogram',
    'audiology',
    'audiometer',
    'audiometric',
    'audiometry',
    'audiotape',
    'audiovisual',
    'audit',
    'audited',
    'auditing',
    'audition',
    'auditioned',
    'auditioning',
    'auditive',
    'auditor',
    'auditorium',
    'auditoriums',
    'auditors',
    'auditory',
    'audits',
    'audubon',
    'aug',
    'augean',
    'augeas',
    'augend',
    'auger',
    'aught',
    'augite',
    'augitic',
    'augment',
    'augmentation',
    'augmentative',
    'augmented',
    'augmentin',
    'augmenting',
    'augments',
    'augur',
    'auguring',
    'augury',
    'august',
    'augusta',
    'augustan',
    'auguste',
    'augustine',
    'augustinian',
    'augustus',
    'auk',
    'auklet',
    'auks',
    'aulacorhyncus',
    'auld',
    'aulostomidae',
    'aulostomus',
    'aum',
    'aunt',
    'auntie',
    'aunty',
    'aura',
    'aural',
    'aurantiacum',
    'aurar',
    'auratus',
    'aureate',
    'aurelius',
    'aureolaria',
    'aureole',
    'aureomycin',
    'auric',
    'auricle',
    'auricles',
    'auricula',
    'auricular',
    'auriculare',
    'auricularia',
    'auriculariaceae',
    'auriculariales',
    'auriculate',
    'auriculated',
    'auriculoventricular',
    'auriferous',
    'auriform',
    'aurify',
    'auriga',
    'aurignacian',
    'auriparus',
    'auriscope',
    'aurochs',
    'aurora',
    'auroral',
    'auroras',
    'aurorean',
    'auroscope',
    'aurous',
    'auschwitz',
    'auscultate',
    'auscultation',
    'auscultatory',
    'auspex',
    'auspicate',
    'auspicated',
    'auspice',
    'auspices',
    'auspicious',
    'auspiciousness',
    'aussie',
    'austen',
    'austenite',
    'austenitic',
    'austere',
    'austereness',
    'austerity',
    'austerlitz',
    'austin',
    'austral',
    'australasia',
    'australasian',
    'australe',
    'australia',
    'australian',
    'australis',
    'australopithecine',
    'australopithecus',
    'austria',
    'austrian',
    'austrians',
    'austrocedrus',
    'austronesia',
    'austronesian',
    'austrotaxus',
    'autacoid',
    'autacoidal',
    'autarchic',
    'autarchical',
    'autarchy',
    'autarkic',
    'autarkical',
    'autarky',
    'auteur',
    'authentic',
    'authenticate',
    'authenticated',
    'authentication',
    'authenticator',
    'authenticity',
    'author',
    'authored',
    'authoress',
    'authorial',
    'authorisation',
    'authorise',
    'authorised',
    'authoriser',
    'authoritarian',
    'authoritarianism',
    'authoritative',
    'authoritatively',
    'authorities',
    'authority',
    'authorization',
    'authorize',
    'authorized',
    'authorizer',
    'authorizes',
    'authorizing',
    'authors',
    'authorship',
    'autism',
    'autistic',
    'auto',
    'autoantibody',
    'autobahn',
    'autobiographer',
    'autobiographic',
    'autobiographical',
    'autobiography',
    'autobus',
    'autocatalysis',
    'autocatalytic',
    'autochthon',
    'autochthonal',
    'autochthonic',
    'autochthonous',
    'autochthony',
    'autoclave',
    'autocoid',
    'autocracy',
    'autocrat',
    'autocratic',
    'autocue',
    'autodidact',
    'autodidactic',
    'autoecious',
    'autoerotic',
    'autoeroticism',
    'autoerotism',
    'autofluorescence',
    'autofluorescent',
    'autofocus',
    'autogamic',
    'autogamous',
    'autogamy',
    'autogenesis',
    'autogenetic',
    'autogenic',
    'autogenics',
    'autogenous',
    'autogeny',
    'autogiro',
    'autograft',
    'autograph',
    'autographed',
    'autographic',
    'autographs',
    'autogyro',
    'autoicous',
    'autoimmune',
    'autoimmunity',
    'autoinjector',
    'autoinjectors',
    'autolatry',
    'autoloader',
    'autoloading',
    'autologous',
    'autolysis',
    'autolytic',
    'automaker',
    'automat',
    'automate',
    'automated',
    'automatic',
    'automatically',
    'automation',
    'automatise',
    'automatism',
    'automatisms',
    'automatize',
    'automaton',
    'automatonlike',
    'automeris',
    'automobile',
    'automobiles',
    'automobilist',
    'automotive',
    'automysophobia',
    'autonomic',
    'autonomous',
    'autonomus',
    'autonomy',
    'autophyte',
    'autophytic',
    'autopilot',
    'autoplastic',
    'autoplasty',
    'autopsy',
    'autoradiograph',
    'autoradiographic',
    'autoradiography',
    'autoregulation',
    'autosemantic',
    'autosexing',
    'autosomal',
    'autosome',
    'autostrada',
    'autosuggestion',
    'autotelic',
    'autotelism',
    'autotomic',
    'autotomise',
    'autotomize',
    'autotomy',
    'autotroph',
    'autotrophic',
    'autotype',
    'autotypic',
    'autotypy',
    'autumn',
    'autumnal',
    'auvergne',
    'auxesis',
    'auxetic',
    'auxiliary',
    'auxin',
    'auxinic',
    'auxins',
    'av',
    'avadavat',
    'avadavats',
    'avahi',
    'avail',
    'availability',
    'available',
    'availableness',
    'availed',
    'availeth',
    'avalanche',
    'avalokiteshvara',
    'avalokitesvara',
    'avaram',
    'avarice',
    'avaricious',
    'avariciousness',
    'avaritia',
    'avascular',
    'avatar',
    'avellan',
    'avellane',
    'avena',
    'avenge',
    'avenged',
    'avenger',
    'avenges',
    'avens',
    'aventail',
    'aventurine',
    'avenue',
    'avenues',
    'aver',
    'average',
    'averaged',
    'averageness',
    'averages',
    'averaging',
    'averment',
    'averrhoa',
    'averroes',
    'averse',
    'aversion',
    'aversive',
    'avert',
    'avertable',
    'averted',
    'avertible',
    'averting',
    'aves',
    'avesta',
    'avestan',
    'avian',
    'avianise',
    'avianize',
    'aviary',
    'aviate',
    'aviation',
    'aviator',
    'aviatress',
    'aviatrix',
    'avicenna',
    'avicennia',
    'avicenniaceae',
    'avid',
    'avidity',
    'avidness',
    'avifauna',
    'avifaunal',
    'avifaunistic',
    'avignon',
    'avionic',
    'avionics',
    'avirulent',
    'avitaminosis',
    'avitaminotic',
    'aviv',
    'avo',
    'avocado',
    'avocation',
    'avocational',
    'avocet',
    'avocets',
    'avogadro',
    'avoid',
    'avoidable',
    'avoidance',
    'avoided',
    'avoiding',
    'avoids',
    'avoirdupois',
    'avon',
    'avos',
    'avouch',
    'avouchment',
    'avow',
    'avowal',
    'avowed',
    'avower',
    'avulse',
    'avulsion',
    'avuncular',
    'await',
    'awaited',
    'awaiting',
    'awaits',
    'awake',
    'awaken',
    'awakened',
    'awakening',
    'awakens',
    'award',
    'awarded',
    'awarding',
    'awards',
    'aware',
    'awareness',
    'away',
    'awayness',
    'awe',
    'aweary',
    'awed',
    'aweigh',
    'aweless',
    'awesome',
    'awestricken',
    'awestruck',
    'awful',
    'awfulness',
    'awheel',
    'awing',
    'awkward',
    'awkwardly',
    'awkwardness',
    'awl',
    'awless',
    'awlwort',
    'awn',
    'awned',
    'awning',
    'awninged',
    'awnless',
    'awns',
    'awny',
    'awoke',
    'awol',
    'ax',
    'axe',
    'axed',
    'axenic',
    'axerophthol',
    'axes',
    'axial',
    'axil',
    'axile',
    'axilla',
    'axillaris',
    'axillary',
    'axils',
    'axiological',
    'axiology',
    'axiom',
    'axiomatic',
    'axiomatical',
    'axioms',
    'axis',
    'axle',
    'axles',
    'axletree',
    'axolemma',
    'axolotl',
    'axon',
    'axonal',
    'axone',
    'axons',
    'axseed',
    'ayah',
    'ayapana',
    'ayatollah',
    'ayin',
    'ayr',
    'ayrshire',
    'aythya',
    'ayurveda',
    'az',
    'azactam',
    'azadirachta',
    'azadirachtin',
    'azalea',
    'azaleastrum',
    'azathioprine',
    'azedarach',
    'azederach',
    'azerbaijan',
    'azerbaijani',
    'azerbajdzhan',
    'azeri',
    'azide',
    'azido',
    'azimuth',
    'azimuthal',
    'azithromycin',
    'azo',
    'azoic',
    'azoimide',
    'azolla',
    'azollaceae',
    'azonal',
    'azonic',
    'azores',
    'azotaemia',
    'azote',
    'azotemia',
    'azotemic',
    'azotic',
    'azoturia',
    'azov',
    'azt',
    'aztec',
    'aztecan',
    'aztecs',
    'aztreonam',
    'azure',
    'azured',
    'azurite',
    'azygos',
    'azygous',
    'azymia']



# -*- coding: utf-8 -*-


import logging
from hashlib import md5


# TODO: consider incorporating these comments - https://blog.guilatrova.dev/how-to-log-in-python-like-a-pro/
logging.basicConfig(
    format='%(asctime)s : %(levelname)s : %(filename)s : %(funcName)s() : %(lineno)d : %(message)s',
    level=logging.DEBUG)


class BaseObject(object):

    def __init__(self,
                 component_name: str):
        """ Change Log

        Created:
            29-Sept-2021
            craigtrim@gmail.com
        Updated:
            31-Mar-2023
            craigtrim@gmail.com
            *   add hash function
                https://github.com/craigtrim/baseblock/issues/5#issuecomment-1492393613

        Args:
            component_name (str): the name of the component to log for
        """
        self.logger = logging.getLogger(component_name)
        isEnabledFor = self.logger.isEnabledFor
        self.isEnabledForDebug = isEnabledFor(logging.DEBUG)
        self.isEnabledForInfo = isEnabledFor(logging.INFO)
        self.isEnabledForWarning = isEnabledFor(logging.WARNING)

    def get_logger(self) -> logging.Logger:
        return self.logger

    def component_name(obj: object) -> str:
        return str(obj.__class__).split("<class '")[-1].split("'")[0]

    @staticmethod
    def uuid_generator() -> str:
        from uuid import uuid1
        return str(uuid1()).replace('-', '_')

    @staticmethod
    def md5hash(input: str) -> int:
        if type(input) != str:
            raise NotImplementedError(type(input))

        return int(md5(input.encode('utf-8')).hexdigest(), 16)
